#
# spec file for package spyder
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The test suite is very peculiar about the testing environment, impossible to replicate for rpmbuild
# Also, the tests fail randomly with segfaults on the obs servers
# You MUST checkout the app in your live system and play with it before submitting an update.
%bcond_with     test
Name:           spyder
Version:        6.0.7
Release:        1.1
Summary:        The Scientific Python Development Environment
License:        MIT
Group:          Development/Languages/Python
URL:            https://www.spyder-ide.org/
Source:         https://github.com/spyder-ide/spyder/archive/v%{version}.tar.gz#/spyder-%{version}.tar.gz
Source1:        spyder-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.7
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools >= 49.6.0
BuildRequires:  python3-wheel
Requires:       %{name}-lang
Requires:       python3-PyQt6 >= 6.5
Requires:       python3-PyQt6-WebEngine >= 6.5
Requires:       python3-Pygments >= 2.0
Requires:       python3-QtPy >= 2.4
Requires:       python3-Rtree >= 0.9.7
Requires:       python3-Sphinx >= 0.6.6
Requires:       python3-aiohttp >= 3.9.3
Requires:       python3-atomicwrites >= 1.2.0
Requires:       python3-bcrypt >= 4.3.0
Requires:       python3-chardet >= 2.0.0
Requires:       python3-cloudpickle >= 0.5.0
Requires:       python3-cookiecutter >= 1.6.0
Requires:       python3-diff-match-patch >= 20181111
Requires:       python3-importlib-metadata >= 4.6.0
Requires:       python3-intervaltree
Requires:       python3-jellyfish >= 0.7
Requires:       python3-jsonschema >= 3.2.0
Requires:       python3-keyring >= 17.0.0
Requires:       python3-nbconvert >= 4.0
Requires:       python3-numpydoc >= 0.6.0
Requires:       python3-packaging >= 20.0
Requires:       python3-parso >= 0.7.0
Requires:       python3-pexpect >= 4.4.0
Requires:       python3-pickleshare >= 0.4
Requires:       python3-psutil >= 5.3
Requires:       python3-pygithub >= 2.3.0
Requires:       python3-pylint-venv >= 3.0.2
Requires:       python3-pyls-spyder >= 0.4.0
Requires:       python3-pyuca >= 1.2
Requires:       python3-pyxdg >= 0.26
Requires:       python3-pyzmq >= 24
Requires:       python3-qstylizer >= 0.2.2
Requires:       python3-textdistance >= 4.2.0
Requires:       python3-three-merge >= 0.1.1
Requires:       python3-watchdog
Requires:       python3-yarl >= 1.9.4
Requires:       (python3-QDarkStyle >= 3.2.0 with python3-QDarkStyle < 3.3.0)
Requires:       (python3-QtAwesome >= 1.4 with python3-QtAwesome < 1.5)
Requires:       (python3-asyncssh >= 2.14 with python3-asyncssh < 3)
Requires:       (python3-ipython >= 8.13 with python3-ipython < 9)
Requires:       (python3-jedi >= 0.17.2 with python3-jedi < 0.20)
Requires:       (python3-pylint >= 3.1 with python3-pylint < 4)
Requires:       (python3-python-lsp-black >= 2.0.0 with python3-python-lsp-black < 3)
Requires:       (python3-python-lsp-server-all >= 1.12.0 with python3-python-lsp-server-all < 1.13)
Requires:       (python3-qtconsole >= 5.6.1 with python3-qtconsole < 5.7)
Requires:       (python3-spyder-kernels >= 3.0.5 with python3-spyder-kernels < 3.1)
Requires:       (python3-superqt >= 0.6.2 with python3-superqt < 1)
Recommends:     git-core
Recommends:     python3-Cython
Recommends:     python3-Pillow
Recommends:     python3-matplotlib
Recommends:     python3-matplotlib-qt
Recommends:     python3-numpy
Recommends:     python3-opengl
Recommends:     python3-pandas
Recommends:     python3-scipy
Recommends:     python3-sympy
Suggests:       %{name}-line-profiler
Suggests:       %{name}-memory-profiler
Suggests:       %{name}-notebook
Suggests:       %{name}-terminal
Suggests:       %{name}-unittest
Provides:       python3-spyder = %{version}
Provides:       python3-spyderlib = %{version}
Provides:       spyder3 = %{version}
Provides:       spyder3-breakpoints = %{version}
Provides:       spyder3-profiler = %{version}
Provides:       spyder3-pylint = %{version}
Obsoletes:      python3-spyder < %{version}
Obsoletes:      python3-spyderlib < %{version}
Obsoletes:      spyder3 < %{version}
Obsoletes:      spyder3-breakpoints < %{version}
Obsoletes:      spyder3-profiler < %{version}
Obsoletes:      spyder3-pylint < %{version}
BuildArch:      noarch
# SECTION test requirements
%if %{with test}
# purely for testing
BuildRequires:  python3-flaky
BuildRequires:  python3-pyaml
BuildRequires:  python3-pytest >= 5.0
BuildRequires:  python3-pytest-lazy-fixture
BuildRequires:  python3-pytest-mock
BuildRequires:  python3-pytest-order
BuildRequires:  python3-pytest-qt
BuildRequires:  python3-pytest-timeout
BuildRequires:  xdpyinfo
BuildRequires:  xvfb-run
# extras
BuildRequires:  git-core
BuildRequires:  python3-Cython
BuildRequires:  python3-Pillow
BuildRequires:  python3-matplotlib
BuildRequires:  python3-matplotlib-qt
BuildRequires:  python3-matplotlib-tk
BuildRequires:  python3-numpy
BuildRequires:  python3-opengl
BuildRequires:  python3-pandas
BuildRequires:  python3-scipy
BuildRequires:  python3-sympy
%endif
# runtime
BuildRequires:  python3-Pygments >= 2.0
BuildRequires:  python3-PyQt6 >= 6.5
BuildRequires:  python3-PyQt6-WebEngine >= 6.5
BuildRequires:  python3-QtPy >= 2.4
BuildRequires:  python3-Rtree >= 0.9.7
BuildRequires:  python3-Sphinx >= 0.6.6
BuildRequires:  python3-aiohttp >= 3.9.3
BuildRequires:  python3-atomicwrites >= 1.2.0
BuildRequires:  python3-bcrypt >= 4.3.0
BuildRequires:  python3-chardet >= 2.0.0
BuildRequires:  python3-cloudpickle >= 0.5.0
BuildRequires:  python3-cookiecutter >= 1.6.0
BuildRequires:  python3-diff-match-patch >= 20181111
BuildRequires:  python3-importlib-metadata >= 4.6.0
BuildRequires:  python3-intervaltree
BuildRequires:  python3-jellyfish >= 0.7
BuildRequires:  python3-jsonschema >= 3.2.0
BuildRequires:  python3-keyring >= 17.0.0
BuildRequires:  python3-nbconvert >= 4.0
BuildRequires:  python3-numpydoc >= 0.6.0
BuildRequires:  python3-packaging >= 20.0
BuildRequires:  python3-parso >= 0.7.0
BuildRequires:  python3-pexpect >= 4.4.0
BuildRequires:  python3-pickleshare >= 0.4
BuildRequires:  python3-psutil >= 5.3
BuildRequires:  python3-pygithub >= 2.3.0
BuildRequires:  python3-pylint-venv >= 3.0.2
BuildRequires:  python3-pyls-spyder >= 0.4.0
BuildRequires:  python3-pyuca >= 1.2
BuildRequires:  python3-pyxdg >= 0.26
BuildRequires:  python3-pyzmq >= 24
BuildRequires:  python3-qstylizer >= 0.2.2
BuildRequires:  python3-textdistance >= 4.2.0
BuildRequires:  python3-three-merge >= 0.1.1
BuildRequires:  python3-watchdog
BuildRequires:  python3-yarl >= 1.9.4
BuildRequires:  (python3-QDarkStyle >= 3.2.0 with python3-QDarkStyle < 3.3.0)
BuildRequires:  (python3-QtAwesome >= 1.4 with python3-QtAwesome < 1.5)
BuildRequires:  (python3-asyncssh >= 2.14 with python3-asyncssh < 3)
BuildRequires:  (python3-ipython >= 8.13 with python3-ipython < 9)
BuildRequires:  (python3-jedi >= 0.17.2 with python3-jedi < 0.20)
BuildRequires:  (python3-pylint >= 3.1 with python3-pylint < 4)
BuildRequires:  (python3-python-lsp-black >= 2.0.0 with python3-python-lsp-black < 3)
BuildRequires:  (python3-python-lsp-server-all >= 1.12.0 with python3-python-lsp-server-all < 1.13)
BuildRequires:  (python3-qtconsole >= 5.6.1 with python3-qtconsole < 5.7)
BuildRequires:  (python3-spyder-kernels >= 3.0.5 with python3-spyder-kernels < 3.1)
BuildRequires:  (python3-superqt >= 0.6.2 with python3-superqt < 1)
# /SECTION

%description
Spyder, the Scientific Python Development Environment, is an
IDE for researchers, engineers and data analysts.
It features a combination of the editing, analysis, debugging
and profiling functionality of a development tool with the
data exploration, interactive execution, deep inspection and
visualization capabilities of an analysis package. Additionally,
Spyder offers built-in integration with scientific
libraries, including NumPy, SciPy, Pandas, IPython, QtConsole,
Matplotlib, SymPy, and more, and can be extended further with
full plugin support.

%package lang
# expansion of lang_package because the macro does not handle the rename
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Provides:       %{name}-lang-all = %{version}
Provides:       spyder3-lang = %{version}
Obsoletes:      spyder3-lang < %{version}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1 -n spyder-%{version}

# Fix wrong-file-end-of-line-encoding RPMLint warning
sed -i 's/\r$//' spyder/app/restart.py
sed -i 's/\r$//' LICENSE.txt CHANGELOG.md

# Remove shebang for non-executable-script RPMLint warning
sed -i -e '/^#!\//, 1d' spyder/app/restart.py

chmod -x spyder/images/*/*.svg

# macOS specific script
rm spyder/utils/check-git.sh

# Upstream brings its fixed versions for pyls, qdarksstyle and spyder-kernels for its
# test environment, but we want to test against installed packages.
rm -r external-deps/*

sed -i "s/installer = 'pip'/installer = 'openSUSE RPM'/" spyder/__init__.py
# avoid mtime destroying dedup
echo "# Unique config __init__.pyc" >> spyder/config/__init__.py

%build
export SPYDER_QT_BINDING=pyqt6
%python3_pyproject_wheel

%install
%python3_pyproject_install

# install the icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
pushd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ln -s %{python3_sitelib}/spyder/images/spyder.svg spyder.svg
popd
pushd %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
ln -s %{_datadir}/icons/spyder.png spyder.png
popd

# get the language files
%find_lang spyder %{name}.lang
# remove source language files
find %{buildroot}%{python3_sitelib}/spyder/locale -name '*.po' -delete
find %{buildroot}%{python3_sitelib}/spyder/locale -name '*.pot' -delete
%fdupes %{buildroot}%{python3_sitelib}

%if %{with test}
%check
export CI=1
sed -i 's/if CI:/if False:/' runtests.py
export LANG=en_US.UTF-8
export PYTHONDONTWRITEBYTECODE=1
mkdir -p /tmp/spyder-abuild

export PYTHONPATH=%{buildroot}%{python3_sitelib}:/tmp/spyder-abuild/testroot/%{python3_sitelib}
# install boilerplate test package
pushd spyder/app/tests/spyder-boilerplate
python3 setup.py install --root /tmp/spyder-abuild/testroot --prefix %{_prefix}
popd

# Upstream splits the tests into slow and fast ones.
# Add all tests which must be skipped into $donttest.

donttest="xxxxxxxxxxxxx"
export donttest

# Can't use pytest-xvfb because the tests leave widgets open and trigger https://github.com/The-Compiler/pytest-xvfb/issues/11
# create test script so that we can use one Xvfb with both test suites:
echo '
#!/bin/bash
set -e
testcmd=(python3 runtests.py -m "not no_xvfb" --timeout 1800 -ra -k "not (${donttest:4})" -x --tb long -l)
"${testcmd[@]}"
"${testcmd[@]}" --run-slow
' > runtests.sh
xvfb-run --server-args "-screen 0 1920x1080x24" bash runtests.sh
%endif

%files
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{_bindir}/spyder
%{_datadir}/applications/spyder.desktop
%{python3_sitelib}/spyder/
%{python3_sitelib}/spyder-%{version}.dist-info
%exclude %{python3_sitelib}/spyder/locale/
%{_datadir}/icons/spyder.png
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/spyder.svg
%{_datadir}/icons/hicolor/128x128/apps/spyder.png
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/org.spyder_ide.spyder.appdata.xml

%files lang -f %{name}.lang
%license LICENSE.txt
%dir %{python3_sitelib}/spyder/locale/
%dir %{python3_sitelib}/spyder/locale/*
%dir %{python3_sitelib}/spyder/locale/*/LC_MESSAGES

%changelog
* Thu May 29 2025 Ben Greiner <code@bnavigator.de>
- Update to 6.0.7
  * Fix failure to show plots in the Plots pane due to faulty
    traitlets versions.
- Release 6.0.6
  [#]# New features
  * Make Editor annotations (like FIXME or HINT) work in lowercase.
  * Retore Quit action to the the IPython console context menu.
  * Don't advance line when running code if there's selected text
    in the Editor.
  [#]# Important fixes
  * Prevent breakpoints from disappearing when formatting code.
  * Fix remote connections error when using the Key file
    authentication method.
  * Respect case sensitivity of working directory when running
    code.
  * Disable fullscreen mode when running on the Windows Subsystem
    for Linux.
  * Several fixes to prevent the Editor and Find panes from taking
    too much horizontal space.
  * Show a better error message when failing to open objects in the
    Variable Explorer due to a mismatch of Python versions.
  * Fix opening Files pane context menu when clicking on its blank
    area.
  * Remove QtWebEngine requirement to show the Help Spyder action.
  * Prevent Matplotlib cache font message from being displayed.
  * Ensure color scheme changes are applied to all the open files.
- Release 6.0.5
  [#]# New features
  * Add option to the Projects options menu to disable file
    searches in the Switcher.
  * Support displaying environments with the same name in the
    IPython Console New console in environment menu.
  [#]# Important fixes
  * Fix Check for updates at startup option when an update is
    declined.
  * Remove mamba from Spyder installers.
  * Several improvements to the Variable Explorer messages shown
    when a variable can't be displayed.
  * Prevent error in Connect to an existing kernel dialog when the
    connection file doesn't exist.
  * Several fixes related to the Run plugin and working directory
    options used to run and debug files.
  * Fix conda executable validation when creating kernels and
    improve feedback in case it's not found.
  * Add message related to support for Pixi environments when
    starting kernels.
  * Improve message related to loading the Spyder icon theme not
    being possible.
  * Prevent Spyder softlock when lossing focus while the tour is
    being shown.
  * Fixes to better handle errors when trying to load .spydata
    files in the Variable Explorer.
  * Fix Editor code folding and indent guides for cloned editors.
- Switch to PyQt6
* Sun Feb  9 2025 Ben Greiner <code@bnavigator.de>
- Update to 6.0.4
  [#]# New features
  * Add command line option to connect to an existing kernel at
    startup.
  * Display a button to select an entire row when hovering it in
    the Variable Explorer.
  [#]# Important fixes
  * Fix error in debugger with Python 3.12.5+
    (_pdbcmd_print_frame_status is not defined message).
  * Improve messages shown when a variable can't be viewed due to a
    missing module.
  * Add validations when doing color theme changes.
  * Fix error when executing in a dedicated console with an
    interpreter without a valid version of spyder-kernels
    installed.
  * Fix setting run configurations per file for multiple runners
    (e.g. the IPython console and Debugger).
  * Fix errors related to the update logic of our standalone
    installers.
  * Make shortcuts that control the Debugger global again.
  * Show debugger buttons in the main toolbar while executing code
    in debugging mode.
  * Restore functionality to select a custom interpreter from the
    statusbar.
  * Fix thumbnails keyboard navigation in the Plots pane when their
    order changes.
  * Handle keyring backend not being available.
  [#]# API changes
  * Add give_focus kwarg to the create_client_for_kernel method of
    the IPython console plugin.
- Release 6.0.3
  [#]# Important fixes
  * Restore widget shortcuts to Preferences and allow to change
    them on the fly.
  * Add support for IPython enhanced tracebacks and use the
    selected color scheme in the editor when showing them.
  * Improve the way users can select the interface font in
    Preferences.
  * Activate Open last closed shortcut and restore some missing
    context menu actions in the Editor.
  * Fix several issues when getting selections to run them.
  * Use the INSTALLER_UNATTENDED environment variable to not launch
    Spyder automatically if installing it in batch/silent mode from
    the standalone installers.
  [#]# API changes
  * Add plugin_name kwarg to the register_shortcut_for_widget
    method of SpyderShortcutsMixin.
  * The add_configuration_observer method was added to
    SpyderConfigurationObserver.
  * Add items_elide_mode kwarg to the constructors of
    SpyderComboBox and SpyderComboBoxWithIcons.
  * The sig_item_in_popup_changed and sig_popup_is_hidden signals
    were added to SpyderComboBox, SpyderComboBoxWithIcons and
    SpyderFontComboBox.
* Sun Nov 17 2024 Ben Greiner <code@bnavigator.de>
- Update to 6.0.2
  [#]# Important fixes
  * Fix plots not being generated with the Matplotlib inline
    backend.
  * Restore missing debugger buttons to the main toolbar.
  * Several fixes and improvements to the update detection
    mechanism.
  * Fix SSH tunneling info handling for remote kernels connection
    and add remote client tests.
  * Handle kernel fault file not being available.
  * Update QtConsole constraint to 5.6.1 to support ANSI codes that
    move the cursor.
  [#]# API changes
  * The sig_is_rendered signal was added to SpyderToolbar.
  * The add_toolbar kwarg of the create_run_button and
    create_run_in_executor_button methods of the Run plugin can now
    accept a dictionary.
  [#]# Issues Closed
  * Issue 22732 - return in finally swallows exceptions (PR 22745
    by @ccordoba12)
  * Issue 22685 - Check update process for 6.0.2 with a rc
    (6.0.2rc1)
  * Issue 22593 - Banner not shown when there are many files open
    in the Editor at startup (PR 22594 by @ccordoba12)
  * Issue 22584 - RuntimeError when setting a layout and the
    IPython console is undocked (PR 22595 by @ccordoba12)
  * Issue 22574 - SpyderCodeRunner._debugger_exec error when
    starting the debugger from Spyder 6.0.1 (PR 22633 by
    @ccordoba12)
  * Issue 22572 - Spyder encounters an internal problem after
    declining update to 6.0.1 (PR 22598 by @mrclary)
  * Issue 22566 - Standalone installer shows 404 error on
    spyder-conda-lock.zip (PR 22598 by @mrclary)
  * Issue 22555 - Remote spyder kernel not connecting (PR 22691 by
    @hlouzada)
  * Issue 22551 - Error message "the system cannot find the path
    specified" upon trying to start the kernel (PR 22575 by
    @ccordoba12)
  * Issue 22546 - UnicodeDecodeError when changing files with an
    open project (PR 22656 by @ccordoba12)
  * Issue 22448 - TypeError on connecting to spyder-notebook kernel
    (PR 22628 by @dalthviz)
  * Issue 22434 - Spyder 6: Debugging buttons missing from the main
    toolbar (PR 22702 by @ccordoba12)
  * Issue 22420 - Plots not showing in Spyder 6 using external
    Python interpreter (PR 22664 by @ccordoba12)
  * Issue 22407 - Update mechanism not working for Spyder 6.0
    installed from Fedora distro package (PR 22631 by @mrclary)
  * Issue 6172 - TQDM progress bar is not displayed correctly in
    the console (PR 22718 by @dalthviz)
  [#]# Pull Requests Merged
  * PR 22785: Improve version update instructions on RELEASE.md, by
    @dalthviz
  * PR 22771: Update dev version from alpha to rc, by @dalthviz
  * PR 22760: Update core dependencies for 6.0.2, by @dalthviz
  * PR 22759: Update spyder-kernels to 3.0.1, by @dalthviz
  * PR 22757: Mention that we need to publish release candidates
    for bugfix versions in release instructions, by @ccordoba12
  * PR 22753: Update translations from Crowdin, by @spyder-bot
  * PR 22752: Update translations for 6.0.2, by @dalthviz
  * PR 22745: Remove unnecessary return in a try/finally statement
    (Files), by @ccordoba12 (22732)
  * PR 22718: Update QtConsole subrepo to take into account changes
    to support cursor move actions, by @dalthviz (6172)
  * PR 22709: Update installing developer repos to accommodate
    dist-info, by @mrclary
  * PR 22702: Restore buttons that control the debugger to the main
    toolbar, by @ccordoba12 (22434)
  * PR 22699: Add Help Spyder entry to the Help menu (Application),
    by @ccordoba12
  * PR 22692: Configure spyder-remote-services as an external
    dependency for the remote client tests, by @hlouzada
  * PR 22691: Provide username, host and port from hostname info in
    ssh tunnels, by @hlouzada (22555)
  * PR 22668: Don't use hard-coded path to Python in script shebang
    used to launch Spyder, by @Flamefire
  * PR 22664: Manually register the Matplotlib inline backend in
    case it hasn't, by @ccordoba12 (22420)
  * PR 22656: Always use utf-8 when handling QByteArray data in
    ProcessWorker (Utils), by @ccordoba12 (22546)
  * PR 22654: Some small fixes to the Maintenance instructions, by
    @ccordoba12
  * PR 22636: Simplify min/max required versions of spyder-kernels
    in the stable branch (IPython console), by @ccordoba12
  * PR 22633: Fix debug file and cell buttons in Debugger toolbar,
    by @ccordoba12 (22574)
  * PR 22631: Do not check for updates if Spyder is in a system or
    managed environment, by @mrclary (22407)
  * PR 22628: Handle case when kernel fault file doesn't exist and
    show error with info explaining that no connection was possible
    (IPython Console), by @dalthviz (22448)
  * PR 22621: Fix setting of working directory in Profiler plugin,
    by @rear1019
  * PR 22618: Fix test_copy_paste_autoindent forcing text over the
    clipboard to work (Editor), by @dalthviz
  * PR 22598: Check for asset availability when checking for
    updates, by @mrclary (22572, 22566)
  * PR 22597: Minor updates to the installer, by @mrclary
  * PR 22595: Dock all undocked plugins before applying a layout,
    by @ccordoba12 (22584)
  * PR 22594: Set shell banner attribute to be the one computed by
    us (IPython console), by @ccordoba12 (22593)
  * PR 22577: Pin micromamba to the last version before 2.0 to
    prevent hangs (CI), by @ccordoba12
  * PR 22575: Add harmless OpenCL warning to bening errors (IPython
    console), by @ccordoba12 (22551)
  * PR 22527: Add initial tests for the Remote client plugin, by
    @hlouzada
* Thu Sep 26 2024 Ben Greiner <code@bnavigator.de>
- Update to 6.0.1
  * Fix Spyder hanging at startup on Linux when started in a
    terminal in background mode.
  * Fix appeal/sponsor Spyder message being shown at every startup.
  * Avoid crashes at startup from faulty/outdated external plugins.
  * Fix errors related to unmaximazing panes and layout changes.
* Sun Sep  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 6.0.0
  [#]# New features
  * New installers for Windows, Linux and macOS based on Conda and
    Conda-forge. They come up with a more robust update process and
    are based on Python 3.11.
  * Add a Debugger pane to explore the stack frame of the current
    debugging session.
  * Add a button to the Debugger pane to pause the current code
    execution and enter the debugger afterwards.
  * Add submenu to the Consoles menu to start a new console for a
    specific Conda or Pyenv environment.
  * Add ability to refresh the open Variable Explorer viewers to
    reflect the current variable value.
  * Add initial support to automatically connect to remote servers
    through SSH and run code in them. This functionality can be
    found in the menu Consoles > New console in remote server.
  * Show plots generated in the Variable Explorer or its viewers in
    the Plots pane.
  * Show Matplotlib backend and Python environment information in
    the status bar.
  * Make kernel restarts be much faster for the current
    interpreter.
  * Add experimental support for Qt 6 and increase minimal required
    version to Qt 5.15.
  * Turn runfile, debugfile, runcell and related commands into
    IPython magics.
  [#]# Important fixes
  * Environment variables declared in ~/.bashrc or ~/.zhrc are
    detected and passed to the IPython console.
  * Support all real number dtypes in the dataframe viewer.
  * Respect Matplotlib user settings configured outside Spyder.
  * Increase DPI of Matplotlib plots so they look better in high
    resolution screens.
  * Allow to copy the absolute and relative paths of the current
    file to the tabs' context menu of the Editor.
  * Restore ability to load Hdf5 and Dicom files through the
    Variable Explorer (this was working in Spyder 4 and before).
  * Add ability to disable external plugins in Preferences >
    Plugins.
  * Use a simpler filesystem watcher in Projects to improve
    performance.
  [#]# UX/UI improvements
  * Make Spyder accept Chinese, Korean or Japanese input on Linux
    by adding fcitx-qt5 as a new dependency (in conda environments
    only).
  * The file switcher can browse and open files present in the
    current project ( in conda environments or if the fzf package
    is installed).
  * Improve how options are displayed and handled in several
    Variable Explorer viewers.
  * The interface font used by the entire application can be
    configured in Preferences > Appearance.
  * Files can be opened in the editor by pasting their path in the
    Working Directory toolbar.
  * Add a new button to the Variable Explorer to indicate when
    variables are being filtered.
  * Show intro message for panes that don't display content at
    startup.
  [#]# New, updated and removed plugins
  * Add a Switcher plugin for the files and symbols switcher.
  * Add a Debugger plugin to centralize all functionality related
    to debugging.
  * Add an External Terminal plugin to execute Python and
    Bash/Batch/PS1 files on a system terminal.
  * Generalize the Run plugin to support generic inputs and
    executors. This allows plugins to declare what kind of inputs
    (i.e. file, cell or selection) they can execute and how they
    will display the result.
  * Declare a proper API for the Projects plugin.
  * The Editor now uses the API introduced in Spyder 5. That was
    the last built-in plugin that needed to be migrated to it.
  * The Breakpoints plugin was removed and its functionality moved
    to the Debugger one.
  [#]# New API features
  * SpyderPluginV2.get_description must be a static method and
    SpyderPluginV2.get_icon a class or static method. This is
    necessary to display the list of available plugins in
    Preferences in a more user-friendly way (see PR PR 21101 for
    the details).
  * SpyderPlugin and SpyderPluginWidget are no longer exposed in
    the public API. They will be removed in Spyder 6.1.
  * All comboboxes must inherit from SpyderComboBox or related
    subclasses in spyder.api.widgets.comboboxes. Comboboxes that
    inherit directly from QComboBox won't follow Spyder's graphical
    style.
  * All menus must inherit from SpyderMenu in
    spyder.api.widgets.menus.
  * All dialog button boxes must inherit from SpyderDialogButtonBox
    in spyder.api.widgets.dialogs.
  * Helper classes were added to spyder.api.fonts to get and set
    the fonts used in Spyder in different widgets.
  * Helper classes were added to spyder.api.shortcuts to get and
    set keyboard shortcuts.
  * AsyncDispatcher was added to spyder.api.asyncdispatcher to run
    asyncio code in Spyder. Only Qt signals can be attached to
    asyncio future.add_done_callback calls to avoid segfaults.
  * ShellConnectStatusBarWidget was added to
    spyder.api.shellconnect.status to create status bar widgets
    connected to the current console.
- Clean test deselection, we are currently not able to run any
  tests.
* Thu Aug 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.6
  [#]# Important fixes
  * Fix several erros related with panes tabification and in
    general when some plugins are disabled/missing.
  * Fix error on file dialogs extensions filter.
  * Fix micromamba usage on arm64 macOS installers.
  * Remove dependency on pkg_resources and make PyQtWebEngine
    optional.
  [#]# Issues Closed
  * Issue 22376 - Spyder 5.5.6 release (PR 22385 by @dalthviz)
  * Issue 22248 - On macOS "Save as..." always defaults to saving
    with ".R" extension rather than ".py" (PR 22270 by @mrclary)
  * Issue 22233 - Using miniconda env creates a bad CPU type error
    with macOS installer in M1 laptops (PR 22265 by @mrclary)
  * Issue 21545 - Use importlib.metadata when trying to get package
    version (PR 22244 by @hmaarrfk)
  [#]# Pull Requests Merged
  * PR 22385 - PR: Update dependencies for 5.5.6, by @dalthviz
    (22376)
  * PR 22372 - PR: Update the python-lsp-server subrepo, by
    @ccordoba12
  * PR 22288 - PR: Fix several errors with missing plugins when
    setting a layout, by @ccordoba12
  * PR 22270 - PR: Remove a non-ascii file extension from
    QFileDialog filter, by @mrclary (22248)
  * PR 22265 - PR: Use the correct micromamba for arm64
    architecture on macOS (Installers), by @mrclary (22233)
  * PR 22244 - PR: Remove dependency on pkg_resources and use
    importlib-metadata instead, by @hmaarrfk (21545)
  * PR 22237 - PR: Fix failing tests due to Numpy 2.0 (Testing), by
    @ccordoba12
  * PR 22199 - PR: Fix error when plugins required for tabification
    are unavailable (Layout), by @hmaarrfk
  * PR 22198 - PR: Backport of PR 22196 (Make QtWebEngine
    Optional), by @hmaarrfk
  * PR 21539 - PR: Update translations from Crowdin, by @spyder-bot
* Thu Jul 11 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.5
  * Fix to ensure compatibility with matplotlib 3.9.0.
  * Fix kernel start when connection file has spaces in its path.
  * Improve compatibility with PySide2.
  * Handle no output/error output when checking for updates on
    conda installations.
  * Fix installers update validation logic to choose installer
    executable name to download/use.
* Mon Apr 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.4
  * Update QtAwesome version constraint to >=1.3.1,<1.4.0 (icon
    fonts access issues).
  * Fix kernel start in conda envs with spaces in their directory
    paths.
  * Fix installers update (installers download URL handling).
  * Handle no output when trying to process git data.
- Drop patches
  * spyder-pr21939-qtawesome1.3.patch
  * spyder-pr21942-pylint3.1.patch
* Mon Apr  1 2024 Ben Greiner <code@bnavigator.de>
- Bump pylsp
* Mon Mar 18 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.3
  * Fix critical error when starting IPython console kernels on
    macOS and Linux in conda environments.
- Release 5.5.2
  * Activate environment for consoles that run in the same
    environment as Spyder.
  * Fix IPython kernel hangs when using a different graphic backend
    than Inline.
  * Fix check for updates mechanism when running Spyder from a
    conda installation.
- Add spyder-pr21939-qtawesome1.3.patch gh#spyder-ide/spyder#21939
  but also allow 1.2
- Add spyder-pr21942-pylint3.1.patch gh#spyder-ide/spyder#21942
* Sat Mar  2 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.1
  [#]# New features
  * Add support to format selections with Black.
  [#]# Important fixes
  * Fix several errors when trying to detect if a new Spyder
    version is available.
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.5.0
  [#]# New features
  * Drop support for Python 3.7
  * Drop support for PyQt < 5.10
  * Improvements to the logic that checks available updates and the
    update messages
  * Improvements to the syntax highlighting for match/case keywords
  * Improved compatibility for the standalone installer with
    Windows Server 2016
  * Additional information about Spyder available through
    spyder.appdata.xml
  [#]# Important fixes
  * Fix Outline Explorer Display variables and attributes option
  * Fix disabling completion and linting providers
  * Fix errors when removing language servers configurations
  * Fix Editor replace all occurences when using backslashes
  * Fix errors when restarting external kernels
  * Fix error when using the Online help with Python 3.11
  * Fix debugging after errors via the %%debug magic
  * Fix compatibility with Python 2 environments/custom
    interpreters
  * Fix application window disappearing when changing monitors
  * Fix PYTHONPATH manager logic to get user environment variables
    and detect possible site-packages directories
- Drop spyder-pr21470-pylint3.diff
* Sun Oct 29 2023 Ben Greiner <code@bnavigator.de>
- Raise pylint upper pin (requires update to python-lsp-server)
  * Add spyder-pr21470-pylint3.diff
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.5
  * Fix Editor scrollflags error on Python 3.7
* Thu Aug 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.4
  [#]# New features
  * Add new shortcuts to switch Editor tabs for macOS (Cmd + 8 and
    Cmd + 9)
  * Add syntax highlighting for Python 3.10 missing statements
    (match and case)
  * Improve compatibility with PySide2
  * Improve Editor scrollflags painting (find matches flags painted
    above errors and warnings flags)
  [#]# Important fixes
  * Fix crash when plugins fail their compatibility checks
  * Fix LSP status bar error when cliking it
  * Fix IPython console font size setting
  * Prevent IPython console This version of python seems to be
    incorrectly compiled warning message in Python 3.11
  * Skip some IPython versions with somes bugs and add some error
    catching for the IPython console
  * Fix Editor found results rehighlighting when switching between
    files
  * Fix Editor class/function dropdown widget when using splited
    editors
  * Fix Editor line numbers and autoformat cursor position when the
    wrap lines option is enabled
  * Fix Editor error when removing unsaved files from
    Projects/Files explorer while open in the Editor
  * Prevent Editor QTextCursor::setPosition: Position '-1' out of
    range warning message
  * Fix Find functionality for a single file
  * Fix PYTHONPATH manager focus issues after adding a path
  * Fix Online Help issues when searching for numpy or pandas
  * Fix Windows installer being launched with admin rights after
    installation/autoupdate
  * Fix Windows installer conda environments activation logic when
    there are spaces in the installation path
  * Fix macOS standalone installer workflow and notarization
    process with new certificate
- Raise jedi pin to <0.20
* Thu Apr 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.3
  [#]# New features
  * Add support for QDarkstyle 3.1
  * Add support for Jupyter-client 8
  * Add mambaforge and miniforge when searching for conda
    environments
  [#]# Important fixes
  * Fix IPython Console completions, traceback handling and other
    issues to better support IPython 8.x
  * Fix compatibility issues with PyZMQ 25.x
  * Add warning message before loading spydata files
  * Fix web based widgets display by adding the --no-sandbox
    argument for QtApplication
  * Fix copy and paste shortcuts for the Files and Projects
    explorer panes
  * Fix Editor issues related with handling LSP server failed
    starts
  * Fix Editor issues related with restoring previous session and
    file changes outside Spyder
  * Fix PYTHONPATH manager showing extra paths and other related
    errors
  * Fix update available notification with pip based installations
  * Fix some UX/UI issues for the find replace widget when the
    Editor has a small width
  * Removal of Python 2 related code
* Thu Jan 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.2
  * Fix issues detected with PyZMQ 25
  * Fix dot completions and improve support for files and
    directories completions
  * Fix getting current user enviroment variables
  * Fix cursor position restauration after autoformat when saving
    files
  * Fix error when reverting unexisting files
  * Fix some issues related with Python 3.11 compatibility
* Fri Dec 30 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.4.1
  [#]# New features
  * Support for IPython 8
  * Improvements for code completion and help offered for
    scientific modules (Numpy, Pandas, Matplotlib and Scipy)
  * Improvements to the UX/UI of the FindReplace widget (find and
    replace functionality)
  * New PYTHONPATH manager plugin
  [#]# Important fixes
  * Improve/fix errors regarding the New Window and Split window
    Editor funtionality and general RuntimeErrors on the Editor
  * Improvements when syncing symbols and folding code
    functionality for the Editor
  * Fix PYTHONPATH handling for the IPython console
  * Some fixes for code completion and code style linting
    functionality
  * Some fixes/improvements regarding UX/UI for the IPython console
    pane, menu and context menu generation
  * Some improvements regarding UX/UI for the current working
    directory toolbar
  [#]# New API features
  * Improvements to the way Spyder handles menus sections additions
* Sun Nov  6 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.4.0
  [#]# New features
  * Now the Code Analysis/Pylint plugin uses the current custom
    interpreter/environment if set
  * Option to show user environment variables extended to all
    operative systems (previously available only for Windows)
  [#]# Important fixes
  * Improve Outline Explorer plugin performance and fix updating
    process when it becomes visible
  * Improvements to colors on the dependencies dialog and IPython
    console
  * Fix IPython console issues on the Matplotlib TkInter backend
    with debugging and an increase of CPU and memory usage while in
    an idle state
  * Fix IPython console memory leak when using the Matplotlib Qt
    ackend
  * Fix IPython console input() issue on MacOS
  * Fix IPython console kernel error regarding environment path as
    unexpected argument
  * Fix Spyder 3 icon theme load on Windows with untrusted fonts
    security restrictions
  * Fix the Autoformat files on save functionality to not hang with
    non-Python files
  * Some fixes for cell execution on Python 3.11
  * Some fixes to shortcuts (Switch to Editor, Find Next, Find
    Previous)
  * Some fixes to improve compatibility with PySide2
  * Some fixes to prevent blurry SVG icons
* Wed Aug 31 2022 andy great <andythe_great@pm.me>
- Update to 5.3.3.
  * New features
  * Printing files now uses a light syntax highlighting theme to
    prevent printing files with dark backgrounds.
  * Important fixes
  * Fix several bugs related with the Layout plugin
    (save visible plugins to restore their visiility and tabify
    behavior for external plugins).
  * Fix several bugs related with the focus management between
    the Editor and other panes.
  * Improve Find and Replace speed on the Editor.
* Sat Jul 23 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.3.2
  * New entry from the Editor context menu to Show help for current
    object.
  * Improve UX/UI for the repositioning panes functionality.
  * Fix several bugs related to the debugging functionality (remote
    kernels usage and Pdb history).
  * Fix incompatibility with Pylint 2.14.0+.
  * Fix several bugs related with the Plots pane.
  * Add create_client_for_kernel and rename_client_tab to the
    Ipython Console plugin so that other plugins can access to
    console creation like Spyder-notebook.
* Sun Jun  5 2022 Ben Greiner <code@bnavigator.de>
- Update the requirements, add note about test suite
* Tue May 24 2022 andy great <andythe_great@pm.me>
- Update to version 5.3.1.
  * New features
  * Add a toolbar to the Variable Explorer viewer for dictionaries,
    lists and sets to easily access the functionality available
    through its context menu.
  * Add navigation with extra buttons in the editor for mouses
    that support them.
  * Add --no-web-widgets command line option to disable
    plugins/widgets that use Qt Webengine widgets.
  * Important fixes
  * Fix several important bugs related to the Autoformat on save
    functionality.
  * Fix options related to the Working directory entry in Preferences.
  * Make code completion widget entries accessible to screen readers.
  * New API features
  * Add get_command_line_options to SpyderPluginV2 so that
    plugins can access the command line options passed to Spyder.
  * The current interpreter used by all Spyder plugins can be
    accessed now through the executable option of the Main \
    interpreter plugin.
  * Full changelog here,
  * https://github.com/spyder-ide/spyder/releases/tag/v5.3.1
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.3.0
  * New Run to current line and Run from current line actions in
    the Editor
  * New option to reset per-file run configurations
  * Now the spyder-terminal plugin comes bundled with the
    standalone installers (MacOS and Windows)
  * Now the standalone Windows installers come with Python 3.8.10
  * Drop support for Python 3.6
  * Fix the restart logic in the IPython Console to set Matplotlib
    interactive backends
  * Fix some issues related to Black formatting configuration and
    usage
  * Improve Editor performance by decreasing the amount of requests
    (didChange request) made to the pylsp server
  * Disable Kite provider for completions
  * Require IPython => 7.31.1 due to CVE-2022-21699
  * Several fixes for type errors with Python 3.10
  * New API features
  * New on_close method for the PluginMainWidget class that its
    called on closeEvent
* Fri Mar 25 2022 Ben Greiner <code@bnavigator.de>
- Fix unpinning of IPython and unpin pyls
* Fri Jan 21 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.2.2
  * Fix several issues regarding the IPython Console kernel
    restart, shutdown and bening errors handling
* Sun Dec 19 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.2.1
  * Prevent Spyder from crashing when selecting an interpreter with
    an incorrect spyder-kernels version
  * Optimize several operations in the Editor and IPython Console
* Fri Nov 26 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.2.0
  * Add new entry in preferences to turn off plugins
  * Add experimental support for PySide2
  * Show standard streams when running code in the IPython Console
  * Speed up search in the Find plugin
  * Migrate the IPython Console to the new API
  * Add new mechanism for plugin teardowm
  * Add a way to create stacked widgets connected to the IPython
    Console like Plots and the Variable explorer
- Drop spyder-pr16565-unpin-pylint.patch fixed upstream
- Drop spyder-jupyter_client7.patch  fixed upstream
* Wed Oct 27 2021 Ben Greiner <code@bnavigator.de>
- Add patches required for newer distro packages
  * spyder-pr16565-unpin-pylint.patch gh#spyder-ide/spyder#16565
  * spyder-jupyter_client7.patch
* Mon Sep 20 2021 Ben Greiner <code@bnavigator.de>
- Still crashing the linux kernel. Disable tests. boo#1190482
* Thu Sep 16 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.5
  * Fix docking of external plugins.
  * Catch error when starting watcher (Projects)
  * Improve appearance of toolbar extension button
- Another take on the kernel crash / OOM issue: test everything
  (including slow tests) within one xvfb-run boo#1190482
* Wed Sep 15 2021 Ben Greiner <code@bnavigator.de>
- kernel still crashing. Disable slow tests for now.
* Tue Sep 14 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.4
  * Fix serious memory leaks and improve performance when typing
    in the editor.
  * Fix Issue 16401 - Trim all newlines after the final one when
    saving a file causes Spyder to freeze when saving a blank file
  * Fix Issue 16384 - Editor becomes sluggish when displaying
    errors
  * Fix Issue 16343 - No handler for workspace/executeCommand
    request
- Avoid kernel crash (!?) at testspyder bash function return
  * boo#1190482
* Wed Sep  8 2021 Ben Greiner <code@bnavigator.de>
- Clean a few test skips, add a new one
- remove _constraints
* Mon Sep  6 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.3
  * Fix RTreeError with snippets
  * Fix TypeError with snippets
- Filter new rpmlint 2 errors in spyder-rpmlintrc
* Thu Sep  2 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.2
  * Add an entry called Restart in debug mode to the File menu.
    That will allow users to inspect the log files generated by
    Spyder by going to the menu Tools > Debug logs after the
    restart.
  * Add a new command line option called --conf-dir to set a
    custom configuration directory for Spyder.
  * Show hidden directories in Projects by default.
  * Use toolbar ids and widget/action ids when adding an item to a
    toolbar.
  * Use menu and item ids to add items to the Main Menu plugin.
  * Fix several performance issues in the Editor.
  * Fix slow browsing of variables in the Variable Explorer when
    Numpy and Pandas are not installed.
  * Discard symbols imported from other libraries in the Outline
    pane.
* Fri Aug 20 2021 Ben Greiner <code@bnavigator.de>
- Fix typo: now really skip the test. It did not even fail in
  staging, but still fails in Factory.
* Fri Aug 20 2021 Ben Greiner <code@bnavigator.de>
- Skip one more potentially segfaulting test
* Thu Aug  5 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.1
  * Fix loading internal plugins, which prevents a crash at startup
  in Python 3.8+ and issues with completion and linting in other
  versions.
  * Make functionality related to Jedi work in our Windows
  installer again.
- Release of version 5.1.0
  * New logo, splash screen and design for the "About Spyder"
    dialog.
  * Support Rich and Colorama in the IPython console.
  * Pasting code in the Editor and IPython console preserves
    indentation.
  * Add a new registration mechanism for plugins that allow
    bidirectional dependencies among them. See this page for
    instructions on how to migrate to it.
  * Fix several critical bugs in the Outline pane.
  * Restore ability to ignore linting messages with inline
    comments in the Editor. Supported comments include # noqa and
    [#] analysis:ignore.
  * Improve code completion performance in the Editor.
  * Fix Code analysis pane in the Windows and macOS installers.
  * Decrease startup time.
  * Support Jedi 0.18 and Parso 0.8
- Drop patches merged upstream
  * spyder-pr15657-python-lsp-server.patch
  * spyder-pr16011-pytest-qt-4.patch
- Make use of CI environment variable due to new conftest.py logic
* Tue Jul 13 2021 Ben Greiner <code@bnavigator.de>
- Replace python-python-language-server with python-lsp-server
  * spyder-pr15657-python-lsp-server.patch
  * gh#spyder-ide/spyder#15657
- Support pytest-qt >= 4
  * spyder-pr16011-pytest-qt-4.patch
  * gh#spyder-ide/spyder#16011
* Thu Jun 24 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.5
  * Catch any error when trying to detect if Kite installers are
    available.
  * Add border around WebView widgets
- Drop tame-kite-installer-check.patch, fixed upstream
* Mon Jun 14 2021 Ben Greiner <code@bnavigator.de>
- Add tame-kite-installer-check.patch
* Mon Jun 14 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.4
  * Programmatic addition of new layouts
  * Fix debugger for IPython 7.24.0
  * Fix loading complex third-party plugins
  * Fix errors when restarting kernels
* Fri May 21 2021 Ben Greiner <code@bnavigator.de>
- Unpin watchdog. boo#1186327
- Fix spyder-kernels dep
- reenable ipythonconsole tests for 32-bit: no bpf failures anymore
- reenable dependency checks during tests
* Mon May 17 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.3
  * Add rtree as a dependency for our pip packages.
  * Scroll pager content with keys (IPython console)
  * Move css_path to Appearance config section (IPython Console)
* Mon May 10 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.2
  * Fix error when restarting kernels.
  * Fix outline, folding and go-to-defintion when Kite is
    installed.
  * Make Plots pane show again separate plots generated in
    different consoles.
  * Fix preferences error when following Kite's tutorial.
* Mon Apr 19 2021 Ben Greiner <code@bnavigator.de>
- Add python-language-server[all] requirements and unpin packages
  in generated egg-info/requires.txt because they are checked on
  startup now.
* Sat Apr 17 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.1
  * Avoid false warning about incorrect spyder-kernels version.
  * Fix error when opening a new editor window.
  * Fix error when saving layouts.
  * Fix several style issues.
  * Fix clicking on tracebacks in the IPython console.
- Unpin jedi and parso. python-python-language-server has been
  patched.
* Thu Apr  8 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.0
  * Improved dark theme based on QDarkstyle 3.0.
  * New light theme based on QDarkstyle 3.0.
  * New look and feel for toolbars.
  * New icon set based on Material Design.
  * New API to extend core plugins, with the exception of the
    Editor, IPython console and Projects.
  * New plugins to manage menus, toolbars, layouts, shortcuts,
    preferences and status bar.
  * New architecture to access and write configuration options.
  * New API to declare code completion providers.
  * New registries to access actions, tool buttons, toolbars and
    menus by their identifiers.
* Sun Mar 28 2021 Ben Greiner <code@bnavigator.de>
- Remove removal of early QtWebEngine import before tests. It
  triggered a fallback to testing with qtwebkit which is being
  removed from Tumbleweed
- Switch to xvfb-run instead of pytest-xvfb to avoid
  gh#The-Compiler/pytest-xvfb#11
- Replace pytest-ordering marks with pytest-order
  gh#spyder-ide/spyder#14935
* Thu Mar 25 2021 Ben Greiner <code@bnavigator.de>
- Update to version 4.2.5
  * Fix restoring window properties at startup.
  * Fix a segfault when restarting kernels.
  * Fix a segfault when processing linting results.
* Fri Mar 19 2021 Ben Greiner <code@bnavigator.de>
- Update to version 4.2.4
  * Fix an important error when restarting kernels.
  * Add compatibility with the future Spyder
* Mon Mar 15 2021 Ben Greiner <code@bnavigator.de>
- remove pytest-ordering -- gh#spyder-ide/spyder#14935
* Thu Mar  4 2021 Ben Greiner <code@bnavigator.de>
- Update to version 4.2.3
  * Fix a very visible bug with Kite installation.
  * Make Find pane to correctly highlight results in the editor.
  * Don't show "No such comm" message when restaring kernels.
- Explicitly limit upper version if Jedi and Parso
* Wed Feb 24 2021 Ben Greiner <code@bnavigator.de>
- The apps dialog segfault is back. (QtAwesome, qtwebengine?)
* Mon Feb 22 2021 Ben Greiner <code@bnavigator.de>
- Update to version 4.2.2
  * Improve performance when typing in the editor.
  * Make variable explorer work for kernels started in remote
    servers.
- Drop spyder-pr14514-fix-pandas120.patch merged upstream
* Mon Feb 15 2021 Ben Greiner <code@bnavigator.de>
- Add spyder-pr14514-fix-pandas120.patch to work with pandas 1.2
  gh#spyder-ide/spyder/14514
* Fri Jan 15 2021 Benjamin Greiner <code@bnavigator.de>
- Skip two more tests which are too slow for qtbot on OBS and one
  test producing segfaults.
* Sat Dec 19 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 4.2.1
  * Code folding for cells.
  * Search works as expected for folded regions.
  * IPython Console preferences are applied on the fly.
  * IPython files (*.ipy) are better support in the Editor.
  * Reduce time to show Preferences dialog.
* Sat Dec  5 2020 Benjamin Greiner <code@bnavigator.de>
- Fix appdata.xml install
- Skip some more tests failing on i586
* Thu Nov 12 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 4.2.0
  New features
  * New, self-contained installers for Windows and macOS.
  * Add support for inline and interactive Matplotlib plots in the
    debugger.
  * Automatic detection of conda and pyenv environments in
    Preferences > Python interpreter.
  * Add functionality to do auto-formatting in the Editor. It can
    be triggered in the menu Source > Format file or selection or
    with the shorcut Ctrl+Alt+I (Cmd+Alt+I in macOS).
  * Add support for text snippets in the Editor. The list of
    available snippets is shown in `Preferences > Completion and
    linting > Snippets`.
  * Support caching cells send in succession to the IPython
    console. This will run one cell after the previous one finished.
  * Make variables take precedence over Pdb commands in the
    debugger. In case a variable clashes with a command, you'll
    have to prefix the command with !.
  * Show a message to take a tour of Spyder features the first
    time 4.2.0 is launched.
  * Drop support for Python 2.7 and 3.5.
  Important fixes
  * Improve performance in the Editor when painting indent guides
    and showing linting messages.
  * Prevent the creation of temporary files in Dropbox directories
    after saving in the Editor.
  * Prevent the Outline to degrade performance in the Editor when
    visible. This was achieved by moving this pane to use the LSP
    architecture.
  * Support Jedi 0.17.2
- remove all python flavor expansions -- only single flavor for
  this "app"
- drop spyder-pr13814-completion.patch merged upstream
* Sun Sep 20 2020 Benjamin Greiner <code@bnavigator.de>
- Require a font package for testing to avoid Qt breakpoint trap
  gh#jupyter/qtconsole#443
- Reenable tests for all platforms
- skip another segfaulting test on Leap
* Sat Sep 19 2020 Benjamin Greiner <code@bnavigator.de>
- spyder-pr13814-completion.patch gh#spyder-ide/spyder#13814
  fix test failure with newer qtconsole
* Wed Sep  2 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 4.1.5
  * Add natural sorting for variables in the Variable Explorer.
  * Add shortcut to open files in the Editor in the operating
    system file explorer.
  * Add an option to run lines of code when entering the debugger.
    This is present in Preferences > IPython console > Startup.
  * Fix error when opening projects.
  * Fix error when hovering in the Editor caused by Kite.
  * Don't save files when running cells.
  * Several improvements to the user experience of Files.
- skip another failing test on Leap
* Fri Aug  7 2020 Benjamin Greiner <code@bnavigator.de>
- singlespec automatic conversion of "Requires: python-*" does not
  work for the packagename without "python-"
- only suggest external more intrusive plugins
* Wed Aug  5 2020 Benjamin Greiner <code@bnavigator.de>
- move to Python singlespec
- do not preload qtpy in runtests.py: avoids "Trace/breakpoint traps"
- skip newly failing tests because of meta change
- skip the slow mainwindow test again: the mainwindow fixture is
  leaking file descriptors and causes undeterministic segfaults
  gh#spyder-ide/spyder#13483
* Fri Jul 10 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 4.1.4
  * Important fixes
  * Correctly restart kernels after a crash while running code.
  * Clear variable explorer after a kernel restart.
  * Fix several errors when sorting variables in the variable
    explorer.
  * Fix selection color in several syntax highlighting themes.
  * Support Jedi 0.17.1, which fixes several issues with code
    completion in the editor.
  * Fix errors when running Dask code in the IPython console.
  * Only show folding arrows when the user hovers over them, which
    improves responsiveness in the editor.
  * Fix several problems with the integration between our projects
    and the Python language server.
  * Handle NaT values in the Variable Explorer.
- drop spyder-pr12746-fixtests.patch merged upstream
* Fri May 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- We can be tested using pytest5
- Skip one more timeouting test
* Sat May 16 2020 Benjamin Greiner <code@bnavigator.de>
- increase memory requirement for builds (the tests consume a lot)
* Fri May 15 2020 Benjamin Greiner <code@bnavigator.de>
- update to version 4.1.3
  * New features
  * New files are saved now as Utf-8 (instead of as Ascii).
  * Make functionality to go to the previous/next cursor more intuitive.
  * New dark and light themes for the Online Help pane.
  * Important fixes
  * Make Spyder work on Python 3.8 and Windows.
  * Fix several startup crashes related to problems with Kite.
  * Fix contrast issues present in several syntax highlighting themes.
  * Fix "Directly enter debugging when errors appear" run option.
  * Fix startup crash when Spyder is using the Brazilian Portuguese
    translation.
  * Fix segfault on Unix systems when removing plots.
  * Correctly position linting markers when code is folded in the editor.
  * Correctly show variables while debugging in the Variable Explorer.
- remove patch spyder-pr11704-fixpytestargs.patch merged upstream
  gh#spyder-ide/spyder#11704
- remove spyder-pr12534-closeleaks.patch gh#spyder-ide/spyder#12534
- add spyder-pr12746-fixtests.patch gh#spyder-ide/spyder#12764
- once again rework the set of skipped tests
- run testsuite only on x86_64 for this noarch package. ix86 fails
  upredictably with segfaults on differing tests
* Thu Apr 30 2020 Benjamin Greiner <code@bnavigator.de>
- Close leaks in tests for mainwindow and ipythonconsole
  gh#spyder-ide/spyder#12534
  spyder-pr12534-closeleaks.patch
- Now also run the slow tests except for a few.
- python-opengl is not a requirement
* Tue Apr 14 2020 Benjamin Greiner <code@bnavigator.de>
- More work on running the unit tests. Do not run the slow tests for
  now. (They were not run in the previous setup either)
* Sat Apr  4 2020 Benjamin Greiner <code@bnavigator.de>
- new version 4.1.2
- New features
  Add a new entry to the status bar to show the current
  state of Python language server. This will allow users to
  know if completions, linting and folding are working as
  expected or have issues. Clicking on this entry will also
  show a menu from which is possible to restart the server
  manually.
- Important fixes
  * Completely disable warning informing to restart Spyder
    when a screeresolution is detected on macOS.
  * Show an error message when it's not possible to create a
    special console for Sympy, Cython or Pylab.
  * Restore code folding for all files with less than 2000 lines.
  * Fix showing help for dot object (e.g. `np.sin`) in the
    IPython console.
  * Fix showing kernel initialization error messages on Windows.
- for a full list of issues closed and PRs merge see CHANGELOG.md
- remove patch merged upstream
  spyder-pr11899-fixdeprecation.patch
* Wed Mar 25 2020 Benjamin Greiner <code@bnavigator.de>
- update pyls and spyder kernels dependency
- update the runtime dependency pin for Jedi and parso
- add python-ordering for unittests
* Tue Mar 24 2020 Benjamin Greiner <code@bnavigator.de>
- Rename subpackages and merge the non-optional plugins
- keep upstreams spyder3 filenames
* Sun Mar 22 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Rename package from 'spyder3' to 'spyder'.
* Fri Mar 20 2020 Benjamin Greiner <code@bnavigator.de>
- update to version 4.1.1
  * Add file path completions to the Editor. This works by writing the
    beginning of a file path, either absolute or relative, inside a
    string and pressing `Tab` or `Ctrl+Space` to get completions for
    it.
  * Add a new command line option called `--report-segfault` to be
  able to send segmentation fault reports to Github.
  * Fix a critical error when starting kernels on Windows.
- changelog from version 4.1.0
  * Several improvements to the interface and user experience of the Plots pane.
  * Show hidden files in Files and Project panes.
  * Allow automatic introduction of docstrings in the Sphinx format.
  * Implicitly create a project when Spyder is launched with a folder path as
    argument in the command line
  * Re-add the ability to run IPython magics inside of cells.
  * Allow running PyQt applications multiple times.
  * Make adjustable the maximum number of recent projects in the Projects
  * Disable code folding and indent guides when files have more than 2000 lines
    for performance reasons.
  * Critical performance improvements to the Editor and Files.
  * Several fixes to the autosave mechanism.
  * Preserve creation time when saving files.
  * Don't corrupt symlinks when saving files associated to them.
  * Improve the code completion experience in the Editor.
  * Start kernels in a thread to avoid freezing the entire interface.
  * Correctly update the debugging panel in the Editor when debugging in
    multiple consoles.
  * Make the Code Analysis pane to read the nearest pylintrc file, according to
    the hierarchy defined by Pylint.
- See full list of issues and pull requests in the CHANGELOG.md on
  github#spyder-ide/spyder
- remove patches merged upstream
  0001-fix-hanging-test-when-not-in-git-repository.patch
  0001-only-test-for-git-when-in-git.patch
- spyder3-pr11704-fixpytestargs.patch to call pytest directly
  (upstream PR#11704, issue#11870)
- spyder3-pr11899-fixdeprecation.patch to pass test_arrayeditor_with_inf_array
  (upstream PR#11889, issue#11885)
- remove the compileall calls for tests because they are not installed anymore
- singlespec macros
- remove source language files from lang package
* Wed Mar 18 2020 Benjamin Greiner <code@bnavigator.de>
- disable ipythonconsole plugin tests completely. OBS really does
  not behave well here -- lots of timeout errors.
- move to pytest-xvfb
* Fri Mar 13 2020 Hans-Peter Jansen <hpj@urpla.net>
- disable test_dbg_input (relies on IPythonConsole behaving well in OBS)
- recommend auxiliary spider modules
- fix specific jedi =0.14.1 dependency removal, that triggers a warn dialog
* Tue Feb 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- run spec-cleaner
- Change dependencies spyder3-breakpoints, spyder3-profiler and spyder3-pylint from Recommends to Requires and add spyder3-lang (fixes boo#1163198)
* Thu Feb 13 2020 Benjamin Greiner <code@bnavigator.de>
- fix unit test stall by upstream PR #11547
  0001-fix-hanging-test-when-not-in-git-repository.patch
- skip git tests by 0001-only-test-for-git-when-in-git.patch (PR#11548)
- skip some failing tests due to timeouts
- the plugin directories have moved
- the plugins have no language files anymore -- remove lang packages
- simplify xvfb setup by using xvfb-run
* Tue Jan 28 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove pytest41.patch not needed anymore
- add more needed build dependencies
* Sat Jan 25 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.0.1
  This is a major upgrade from 3.3.6. For an extensive list of fixes
  and updates see https://github.com/spyder-ide/spyder/blob/master/CHANGELOG.md#version-401-2020-01-02
  and below.
* Fri Nov  1 2019 Ondřej Súkup <mimi.vx@gmail.com>
- add pytest41.patch - fix tests with pytest-4+
* Fri Sep 13 2019 Todd R <toddrme2178@gmail.com>
- Fix desktop file categories.
* Mon Aug 19 2019 John Vandenberg <jayvdb@gmail.com>
- Use GitHub release tarball due to missing files in sdist
- Activate and fix tests, skipping tests requiring VCS or Internet
* Thu Jul 25 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Remove version requirement for python3-pyqtwebengine
  - fixes boo#1141974
* Mon Jul 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 3.3.6:
  - Issues Closed:
  - [Issue 9757](https://github.com/spyder-ide/spyder/issues/9757) - Text in help search bar becomes selected once help is displayed ([PR 9760](https://github.com/spyder-ide/spyder/pull/9760))
  - [Issue 8336](https://github.com/spyder-ide/spyder/issues/8336) - AttributeError in profiler ([PR 9758](https://github.com/spyder-ide/spyder/pull/9758))
  - In this release 2 issues were closed.
  - Pull Requests Merged:
  - [PR 9760](https://github.com/spyder-ide/spyder/pull/9760) - PR: Backport PR #9552 ([9757](https://github.com/spyder-ide/spyder/issues/9757))
  - [PR 9758](https://github.com/spyder-ide/spyder/pull/9758) - PR: Avoid an error when profdata is None in Profiler ([8336](https://github.com/spyder-ide/spyder/issues/8336))
  - [PR 9718](https://github.com/spyder-ide/spyder/pull/9718) - PR: Fix completion plugins listening to external hosts
  - In this release 3 pull requests were closed.
* Sun Jun 30 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 3.3.5:
  - New features:
  - Add option to allow users showing/hiding CMD windows created by the
    `subprocess` module on Windows. The option can be found in
    `Preferences > IPython Console > Advanced settings > Windows adjustments`.
  - Issues Closed:
  - [Issue 9520](https://github.com/spyder-ide/spyder/issues/9520) - Can't run profiler ([PR 9652](https://github.com/spyder-ide/spyder/pull/9652))
  - [Issue 9304](https://github.com/spyder-ide/spyder/issues/9304) - PermissionError when trying to load a kernel connection file ([PR 9651](https://github.com/spyder-ide/spyder/pull/9651))
  - [Issue 9262](https://github.com/spyder-ide/spyder/issues/9262) - Only require PyWebEngine on Python 3+ to avoid blocking py2 compat in pip wheels ([PR 9436](https://github.com/spyder-ide/spyder/pull/9436))
  - [Issue 9240](https://github.com/spyder-ide/spyder/issues/9240) - The external system terminal close after running script if the Python console exits due to an exception ([PR 9312](https://github.com/spyder-ide/spyder/pull/9312))
  - [Issue 9221](https://github.com/spyder-ide/spyder/issues/9221) - TypeError: cursor_position_changed ([PR 9650](https://github.com/spyder-ide/spyder/pull/9650))
  - [Issue 9217](https://github.com/spyder-ide/spyder/issues/9217) - ValueError when clicking on a traceback link in the IPython console ([PR 9649](https://github.com/spyder-ide/spyder/pull/9649))
  - [Issue 9143](https://github.com/spyder-ide/spyder/issues/9143) - Help pane doesn't accept aliased modules ([PR 9166](https://github.com/spyder-ide/spyder/pull/9166))
  - [Issue 9113](https://github.com/spyder-ide/spyder/issues/9113) - Opening window in a subprocess from Spyder ([PR 9123](https://github.com/spyder-ide/spyder/pull/9123))
  - [Issue 9093](https://github.com/spyder-ide/spyder/issues/9093) - Error when trying to create spyder.lock on an unwritable config directory ([PR 9098](https://github.com/spyder-ide/spyder/pull/9098))
  - [Issue 9051](https://github.com/spyder-ide/spyder/issues/9051) - Variable explorer viewers go to the background on macOS ([PR 9119](https://github.com/spyder-ide/spyder/pull/9119))
  - In this release 10 issues were closed.
  - Pull Requests Merged:
  - [PR 9658](https://github.com/spyder-ide/spyder/pull/9658) - PR: Require spyder-kernels 0.5.0 in setup.py
  - [PR 9652](https://github.com/spyder-ide/spyder/pull/9652) - PR: Remove usage of QTextCodec because it's not really needed ([9520](https://github.com/spyder-ide/spyder/issues/9520))
  - [PR 9651](https://github.com/spyder-ide/spyder/pull/9651) - PR: Catch error when loading kernel connection file ([9304](https://github.com/spyder-ide/spyder/issues/9304))
  - [PR 9650](https://github.com/spyder-ide/spyder/pull/9650) - PR: Catch an error when disconnecting a signal in calltip widget ([9221](https://github.com/spyder-ide/spyder/issues/9221))
  - [PR 9649](https://github.com/spyder-ide/spyder/pull/9649) - PR: Catch error when pressing the link of a traceback in IPython console ([9217](https://github.com/spyder-ide/spyder/issues/9217))
  - [PR 9436](https://github.com/spyder-ide/spyder/pull/9436) - PR: Require pyqtwebengine only in Python 3 ([9262](https://github.com/spyder-ide/spyder/issues/9262))
  - [PR 9312](https://github.com/spyder-ide/spyder/pull/9312) - PR: Improvements to the cmd used to start external terminals on Windows ([9240](https://github.com/spyder-ide/spyder/issues/9240))
  - [PR 9166](https://github.com/spyder-ide/spyder/pull/9166) - PR: Fix Help plugin string validation for the console ([9143](https://github.com/spyder-ide/spyder/issues/9143))
  - [PR 9123](https://github.com/spyder-ide/spyder/pull/9123) - PR: Add preference to show/hide cmd windows generated by the subprocess module ([9113](https://github.com/spyder-ide/spyder/issues/9113))
  - [PR 9119](https://github.com/spyder-ide/spyder/pull/9119) - PR: Make Variable Explorer viewers stay on top in macOS ([9051](https://github.com/spyder-ide/spyder/issues/9051))
  - [PR 9099](https://github.com/spyder-ide/spyder/pull/9099) - PR: Add sponsors sections and remove relative links to images in Readme
  - [PR 9098](https://github.com/spyder-ide/spyder/pull/9098) - PR: Avoid some permission errors at startup on Windows  ([9093](https://github.com/spyder-ide/spyder/issues/9093))
  - In this release 12 pull requests were closed.
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix jupyter dependencies.
* Sun Apr  7 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add changelog.sh for easier changelog conversion in packaging.
- update to version 3.3.4:
  - New features:
  - Fix several incompatibilities with PyQt5 5.12.
  - Avoid errors when running `turtle` programs in the IPython console
  multiple times.
  - Avoid the UMR to reload modules installed in the user site-packages
  directory.
  - Issues Closed:
  - [Issue 8978](https://github.com/spyder-ide/spyder/issues/8978) - Github login window is resizing automatically ([PR 8993](https://github.com/spyder-ide/spyder/pull/8993))
  - [Issue 8934](https://github.com/spyder-ide/spyder/issues/8934) - IOError raised when completion plugins fail to start ([PR 8950](https://github.com/spyder-ide/spyder/pull/8950))
  - [Issue 8927](https://github.com/spyder-ide/spyder/issues/8927) - Change "Clear variables" to "Remove variables" in French translation ([PR 8951](https://github.com/spyder-ide/spyder/pull/8951))
  - [Issue 8878](https://github.com/spyder-ide/spyder/issues/8878) - Error when try to type opening bracket in console ([PR 8879](https://github.com/spyder-ide/spyder/pull/8879))
  - [Issue 8841](https://github.com/spyder-ide/spyder/issues/8841) - Static Code Analysis can be attempted without selected file ([PR 8921](https://github.com/spyder-ide/spyder/pull/8921))
  - [Issue 8807](https://github.com/spyder-ide/spyder/issues/8807) - Error when saving LANG_FILE ([PR 8808](https://github.com/spyder-ide/spyder/pull/8808))
  - [Issue 8789](https://github.com/spyder-ide/spyder/issues/8789) - spyder_io_hdf5 plugin no longer available ([PR 8790](https://github.com/spyder-ide/spyder/pull/8790))
  - [Issue 8776](https://github.com/spyder-ide/spyder/issues/8776) - Problem with debugfile() in version >= 3.3.0
  - [Issue 8764](https://github.com/spyder-ide/spyder/issues/8764) - VersionConflict when opening a file in the Editor ([PR 8781](https://github.com/spyder-ide/spyder/pull/8781))
  - [Issue 8762](https://github.com/spyder-ide/spyder/issues/8762) - Text written in help pane gets automatically selected and replaced with every keystroke ([PR 8907](https://github.com/spyder-ide/spyder/pull/8907))
  - [Issue 8748](https://github.com/spyder-ide/spyder/issues/8748) - spyder 3.3.3 icon theme Spyder 3 problem with PyQt 5.12 ([PR 8896](https://github.com/spyder-ide/spyder/pull/8896))
  - [Issue 8747](https://github.com/spyder-ide/spyder/issues/8747) - Spyder should depend on QtWebEngine for pyqt >= 5.12 ([PR 8753](https://github.com/spyder-ide/spyder/pull/8753))
  - [Issue 6278](https://github.com/spyder-ide/spyder/issues/6278) - Problems with running turtle programs in Spyder
  - Pull Requests Merged:
  - [PR 9073](https://github.com/spyder-ide/spyder/pull/9073) - PR: Increase minimal required version of spyder-kernels to 0.4.3
  - [PR 9041](https://github.com/spyder-ide/spyder/pull/9041) - PR: Fix a recurrrent error with our IPython console tests
  - [PR 9023](https://github.com/spyder-ide/spyder/pull/9023) - PR: Fix warning and todo action menu entries
  - [PR 9020](https://github.com/spyder-ide/spyder/pull/9020) - PR: Fix our tests on Windows/Python 3.7
  - [PR 8996](https://github.com/spyder-ide/spyder/pull/8996) - PR: Generate PyPI long description from README.md
  - [PR 8993](https://github.com/spyder-ide/spyder/pull/8993) - PR: Fix over-height resize of the Github login dialog ([8978](https://github.com/spyder-ide/spyder/issues/8978))
  - [PR 8953](https://github.com/spyder-ide/spyder/pull/8953) - PR: Compile French translation po file
  - [PR 8951](https://github.com/spyder-ide/spyder/pull/8951) - PR: Change 'Supprimer' for 'Effacer' in remove variables text for French translation ([8927](https://github.com/spyder-ide/spyder/issues/8927))
  - [PR 8950](https://github.com/spyder-ide/spyder/pull/8950) - PR: Don't raise an error if completion plugins fail to start ([8934](https://github.com/spyder-ide/spyder/issues/8934))
  - [PR 8928](https://github.com/spyder-ide/spyder/pull/8928) - PR: Use generic Qt name instead of Qt4 when switching backend for Mayavi
  - [PR 8921](https://github.com/spyder-ide/spyder/pull/8921) - PR: Set enabled value of start_button with is_valid (Static Code Analysis) ([8841](https://github.com/spyder-ide/spyder/issues/8841))
  - [PR 8910](https://github.com/spyder-ide/spyder/pull/8910) - PR: Fix tests on Windows/Python 3.7
  - [PR 8907](https://github.com/spyder-ide/spyder/pull/8907) - PR: Fix force_refresh to only force with valid object entries (Help plugin) ([8762](https://github.com/spyder-ide/spyder/issues/8762))
  - [PR 8899](https://github.com/spyder-ide/spyder/pull/8899) - PR: Run our tests with pip on Windows/Python 3.7
  - [PR 8896](https://github.com/spyder-ide/spyder/pull/8896) - PR: Increase minimal QtAwesome version to 0.5.7 ([8748](https://github.com/spyder-ide/spyder/issues/8748))
  - [PR 8895](https://github.com/spyder-ide/spyder/pull/8895) - PR: Remove Appveyor support and stop testing on Windows/Python 2
  - [PR 8879](https://github.com/spyder-ide/spyder/pull/8879) - PR: Don't fail on UnicodeEncodeError when saving Help's search history to disk ([8878](https://github.com/spyder-ide/spyder/issues/8878))
  - [PR 8808](https://github.com/spyder-ide/spyder/pull/8808) - PR: Avoid errors when trying to save LANG_FILE ([8807](https://github.com/spyder-ide/spyder/issues/8807))
  - [PR 8802](https://github.com/spyder-ide/spyder/pull/8802) - PR: Upgrade Travis config to use Xenial image
  - [PR 8790](https://github.com/spyder-ide/spyder/pull/8790) - PR: Fix missing spyder_io_hdf5 plugin ([8789](https://github.com/spyder-ide/spyder/issues/8789))
  - [PR 8781](https://github.com/spyder-ide/spyder/pull/8781) - PR: Avoid errors when using Pygments to detect the lexer used to highlight a file ([8764](https://github.com/spyder-ide/spyder/issues/8764))
  - [PR 8756](https://github.com/spyder-ide/spyder/pull/8756) - PR: Fix PyQt5 pinning restrictions in setup.py
  - [PR 8753](https://github.com/spyder-ide/spyder/pull/8753) - PR: Add pyqtwebengine as a new dependency ([8747](https://github.com/spyder-ide/spyder/issues/8747))
----
- update to version 3.3.3:
  - New features:
  - Fix an incompatibility with Numpy 1.16 that generated an error
  when trying to open an array in the Variable Explorer.
  - Increase maximum PyQt5 supported version to 5.12
  - Increase minimal required version of spyder-kernels to 0.4.2
  to get important fixes about saving/loading the current
  namespace and skipping installed modules from our User Module
  Reloader (UMR).
  - Issues Closed:
  - [Issue 8697](https://github.com/spyder-ide/spyder/issues/8697) - Starting a python file importing tensorflow the second time results in error
  - [Issue 8681](https://github.com/spyder-ide/spyder/issues/8681) - PYTHONPATH environment variable not inherited if using non-default python interpreter ([PR 8685](https://github.com/spyder-ide/spyder/pull/8685))
  - [Issue 8668](https://github.com/spyder-ide/spyder/issues/8668) - Console throws error about wurlitzer on fresh install
  - [Issue 8582](https://github.com/spyder-ide/spyder/issues/8582) - Spyder encountered a problem when opening numpy array ([PR 8632](https://github.com/spyder-ide/spyder/pull/8632))
  - [Issue 8581](https://github.com/spyder-ide/spyder/issues/8581) - An error ocurred while starting the kernel: b'' ([PR 8736](https://github.com/spyder-ide/spyder/pull/8736))
  - [Issue 8475](https://github.com/spyder-ide/spyder/issues/8475) - pyqt5 Dependency seems outdated ([PR 8530](https://github.com/spyder-ide/spyder/pull/8530))
  - Pull Requests Merged:
  - [PR 8736](https://github.com/spyder-ide/spyder/pull/8736) - PR: Don't show empty kernel error messages ([8581](https://github.com/spyder-ide/spyder/issues/8581))
  - [PR 8731](https://github.com/spyder-ide/spyder/pull/8731) - PR: Backport PR 8559
  - [PR 8728](https://github.com/spyder-ide/spyder/pull/8728) - PR: Increase minimal spyder-kernels version in setup.py to avoid faulty release
  - [PR 8696](https://github.com/spyder-ide/spyder/pull/8696) - PR: Increase minimal required version of spyder-kernels
  - [PR 8689](https://github.com/spyder-ide/spyder/pull/8689) - PR: Backport PR 8363
  - [PR 8686](https://github.com/spyder-ide/spyder/pull/8686) - PR: Backport PR 8452
  - [PR 8685](https://github.com/spyder-ide/spyder/pull/8685) - PR: Avoid dropping predefined PYTHONPATH when using an external interpreter ([8681](https://github.com/spyder-ide/spyder/issues/8681))
  - [PR 8636](https://github.com/spyder-ide/spyder/pull/8636) - PR: Improve warning for when only some namespace objs couldn't be saved
  - [PR 8632](https://github.com/spyder-ide/spyder/pull/8632) - PR: Don't force write flag to True in ArrayEditor, to fix compat with Numpy >=1.16 ([8582](https://github.com/spyder-ide/spyder/issues/8582))
  - [PR 8530](https://github.com/spyder-ide/spyder/pull/8530) - PR: Increase maximum PyQt5 supported version ([8475](https://github.com/spyder-ide/spyder/issues/8475))
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Fix rpmlint issues.
* Wed Jan  2 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 3.3.2:
  - New features
  - Main Window
  * Add new German and Hungarian translations.
  - Preferences
  * Give users the ability to select the OpenGL implementation
    used by Qt. This option can be changed in
    `General > Advanced Settings > Rendering engine`.
  - Find in files
  * Simplify the way to exclude files from search.
  * Fix error that prevented to stop a search when it was in
    progress.
  * Save its options when Spyder is closed.
  - Under the hood
  * Don't remove Spyder's temporary directory when Spyder is
    closed. This avoids conflicts when multiple Spyder
    instances are running.
  - Issues Closed
  * [Issue 8290](https://github.com/spyder-ide/spyder/issues/8290) - spyder.desktop doesn't contain  WMClass variable for grouping windows ([PR 8292](https://github.com/spyder-ide/spyder/pull/8292))
  * [Issue 8236](https://github.com/spyder-ide/spyder/issues/8236) - Update translations for 3.3.2
  * [Issue 8216](https://github.com/spyder-ide/spyder/issues/8216) - Error on startup with non-clean config file (from previous files/projects open?) and recent master builds ([PR 8249](https://github.com/spyder-ide/spyder/pull/8249))
  * [Issue 8179](https://github.com/spyder-ide/spyder/issues/8179) - Error when changing language from French to English ([PR 8188](https://github.com/spyder-ide/spyder/pull/8188))
  * [Issue 8128](https://github.com/spyder-ide/spyder/issues/8128) - Error raises when use multiprocessing
  * [Issue 8103](https://github.com/spyder-ide/spyder/issues/8103) - DeprecationWarning with iPython during executing certain commands in the console.
  * [Issue 8046](https://github.com/spyder-ide/spyder/issues/8046) - PermissionError while launching Spyder ([PR 8048](https://github.com/spyder-ide/spyder/pull/8048))
  * [Issue 8025](https://github.com/spyder-ide/spyder/issues/8025) - Custom interpreters are not shown in "Preferences > Python interpreter" ([PR 8231](https://github.com/spyder-ide/spyder/pull/8231))
  * [Issue 8007](https://github.com/spyder-ide/spyder/issues/8007) - Kernel crash due to file with the same name of a stdlib Python module present in current working directory
  * [Issue 7882](https://github.com/spyder-ide/spyder/issues/7882) - Error while restarting kernel ([PR 7887](https://github.com/spyder-ide/spyder/pull/7887))
  * [Issue 7868](https://github.com/spyder-ide/spyder/issues/7868) - Connect to kernel dialog needs to be clearer that either the SSH keyfile *or* the password is required ([PR 7898](https://github.com/spyder-ide/spyder/pull/7898))
  * [Issue 7862](https://github.com/spyder-ide/spyder/issues/7862) - 4.0beta1 is offered as an update when using a development version and a virtualenv ([PR 7902](https://github.com/spyder-ide/spyder/pull/7902))
  * [Issue 7856](https://github.com/spyder-ide/spyder/issues/7856) - Nbconvert 5.4.0 breaking mainwindow notebook test due to change in output file text ([PR 7860](https://github.com/spyder-ide/spyder/pull/7860))
  * [Issue 7811](https://github.com/spyder-ide/spyder/issues/7811) - Find In Files: empty "Exclude" field makes all files be excluded ([PR 7816](https://github.com/spyder-ide/spyder/pull/7816))
  * [Issue 7810](https://github.com/spyder-ide/spyder/issues/7810) - Find In Files: regexp icon ([PR 7864](https://github.com/spyder-ide/spyder/pull/7864))
  * [Issue 7809](https://github.com/spyder-ide/spyder/issues/7809) - Make visible by default the widget to exclude file types in Find in Files ([PR 7864](https://github.com/spyder-ide/spyder/pull/7864))
  * [Issue 7804](https://github.com/spyder-ide/spyder/issues/7804) - Stopping a search using FindInFiles freezes the app ([PR 7806](https://github.com/spyder-ide/spyder/pull/7806))
  * [Issue 7803](https://github.com/spyder-ide/spyder/issues/7803) - Change the way to exclude file types in Find in files ([PR 7806](https://github.com/spyder-ide/spyder/pull/7806))
  * [Issue 7800](https://github.com/spyder-ide/spyder/issues/7800) - FileNotFoundError when using custom interpreter ([PR 7829](https://github.com/spyder-ide/spyder/pull/7829))
  * [Issue 7753](https://github.com/spyder-ide/spyder/issues/7753) - Error when copying data from a dataframe ([PR 7759](https://github.com/spyder-ide/spyder/pull/7759))
  * [Issue 7748](https://github.com/spyder-ide/spyder/issues/7748) - Cannot import notebook variables ([PR 7761](https://github.com/spyder-ide/spyder/pull/7761))
  * [Issue 7742](https://github.com/spyder-ide/spyder/issues/7742) - Error when dropping files in the Editor ([PR 7764](https://github.com/spyder-ide/spyder/pull/7764))
  * [Issue 7733](https://github.com/spyder-ide/spyder/issues/7733) - Error when browsing git repository ([PR 7766](https://github.com/spyder-ide/spyder/pull/7766))
  * [Issue 7721](https://github.com/spyder-ide/spyder/issues/7721) - Error after upgrading to Python 3.7 ([PR 7807](https://github.com/spyder-ide/spyder/pull/7807))
  * [Issue 7705](https://github.com/spyder-ide/spyder/issues/7705) - Error on saving generated by Pygments lexers ([PR 7712](https://github.com/spyder-ide/spyder/pull/7712))
  * [Issue 7674](https://github.com/spyder-ide/spyder/issues/7674) - New Python interpreter selection combobox displays previous, not actual executable path if selected from file browser ([PR 7715](https://github.com/spyder-ide/spyder/pull/7715))
  * [Issue 7619](https://github.com/spyder-ide/spyder/issues/7619) - Error when trying to display Latex through Matplotlib
  * [Issue 7578](https://github.com/spyder-ide/spyder/issues/7578) - AttributeError: 'NoneType' object has no attribute 'input' ([PR 7716](https://github.com/spyder-ide/spyder/pull/7716))
  * [Issue 7561](https://github.com/spyder-ide/spyder/issues/7561) - Annoying "Are you sure you want to restart the kernel?" ([PR 7694](https://github.com/spyder-ide/spyder/pull/7694))
  * [Issue 7552](https://github.com/spyder-ide/spyder/issues/7552) - TypeError: scaledToWidth in the IPython console
  * [Issue 7447](https://github.com/spyder-ide/spyder/issues/7447) - Main window is black when starting Spyder over ssh/X11 ([PR 7859](https://github.com/spyder-ide/spyder/pull/7859))
  * [Issue 7302](https://github.com/spyder-ide/spyder/issues/7302) - PermissionError when launching kernel ([PR 7717](https://github.com/spyder-ide/spyder/pull/7717))
  * [Issue 7244](https://github.com/spyder-ide/spyder/issues/7244) - AttributeError when pasting list in collectionseditor.py ([PR 7817](https://github.com/spyder-ide/spyder/pull/7817))
  * [Issue 7236](https://github.com/spyder-ide/spyder/issues/7236) - UnicodeDecodeError when changing PYTHONPATH in Python 2 ([PR 7655](https://github.com/spyder-ide/spyder/pull/7655))
  * [Issue 7195](https://github.com/spyder-ide/spyder/issues/7195) - Crash when displaying a pandas data frame with a column containing a data frame ([PR 8114](https://github.com/spyder-ide/spyder/pull/8114))
  * [Issue 7177](https://github.com/spyder-ide/spyder/issues/7177) - Error when passing a regexp to the findreplace widget ([PR 8115](https://github.com/spyder-ide/spyder/pull/8115))
  * [Issue 6936](https://github.com/spyder-ide/spyder/issues/6936) - Data Type of customized class is changed to base class when viewed in the Variable Explorer ([PR 7679](https://github.com/spyder-ide/spyder/pull/7679))
  * [Issue 6535](https://github.com/spyder-ide/spyder/issues/6535) - Text in "About Spyder" menu is not selectable ([PR 7727](https://github.com/spyder-ide/spyder/pull/7727))
  * [Issue 6218](https://github.com/spyder-ide/spyder/issues/6218) - UnicodeDecodeError when truncating results in Find in files ([PR 7812](https://github.com/spyder-ide/spyder/pull/7812))
  * [Issue 6176](https://github.com/spyder-ide/spyder/issues/6176) - Find in Files options not saved to spyder.ini ([PR 7863](https://github.com/spyder-ide/spyder/pull/7863))
  * [Issue 5898](https://github.com/spyder-ide/spyder/issues/5898) - Closing all files in split pane view with at least 2 open then clicking any menu triggers RuntimeError
  * [Issue 4474](https://github.com/spyder-ide/spyder/issues/4474) - Find in files exclude as a textbox is very limited (not very UX friendly either) ([PR 7864](https://github.com/spyder-ide/spyder/pull/7864))
  * [Issue 4291](https://github.com/spyder-ide/spyder/issues/4291) - Menu items don't show in full-screen mode ([PR 7720](https://github.com/spyder-ide/spyder/pull/7720))
  * [Issue 3777](https://github.com/spyder-ide/spyder/issues/3777) - Output of C extensions is not shown in IPython console
  * [Issue 937](https://github.com/spyder-ide/spyder/issues/937) - Editor maximized - Run script - console takes most of screen ([PR 7205](https://github.com/spyder-ide/spyder/pull/7205))
  * In this release 45 issues were closed.
  - Pull Requests Merged
  * [PR 8292](https://github.com/spyder-ide/spyder/pull/8292) - PR: Add StartupWMClass to Linux desktop files ([8290](https://github.com/spyder-ide/spyder/issues/8290))
  * [PR 8278](https://github.com/spyder-ide/spyder/pull/8278) - PR: Update Spanish translation for 3.3.2
  * [PR 8264](https://github.com/spyder-ide/spyder/pull/8264) - PR: French Translation for 3.3.2
  * [PR 8263](https://github.com/spyder-ide/spyder/pull/8263) - PR: Fix tests in Appveyor/Python 2
  * [PR 8261](https://github.com/spyder-ide/spyder/pull/8261) - PR: Fix error in Pydoc widget when quitting server in Python 2
  * [PR 8259](https://github.com/spyder-ide/spyder/pull/8259) - PR: Fixes due to the new Pytest 4
  * [PR 8256](https://github.com/spyder-ide/spyder/pull/8256) - PR: Add German translation
  * [PR 8255](https://github.com/spyder-ide/spyder/pull/8255) - PR: Update Japanese translation for 3.3.2
  * [PR 8250](https://github.com/spyder-ide/spyder/pull/8250) - PR: Update Hungarian translation for 3.3.2
  * [PR 8249](https://github.com/spyder-ide/spyder/pull/8249) - PR: Prevent an error during the initialization of the Editor plugin ([8216](https://github.com/spyder-ide/spyder/issues/8216))
  * [PR 8248](https://github.com/spyder-ide/spyder/pull/8248) - PR: Update Russian translation
  * [PR 8232](https://github.com/spyder-ide/spyder/pull/8232) - PR: Fix passing --run-slow to runtests.py
  * [PR 8231](https://github.com/spyder-ide/spyder/pull/8231) - PR: Don't associate the combobox of FileComboBox to the same option as its lineedit ([8025](https://github.com/spyder-ide/spyder/issues/8025))
  * [PR 8188](https://github.com/spyder-ide/spyder/pull/8188) - PR: Catch errors when trying to change the interface language ([8179](https://github.com/spyder-ide/spyder/issues/8179))
  * [PR 8187](https://github.com/spyder-ide/spyder/pull/8187) - PR: Don't install qtconsole from git on Appveyor because it's generating errors
  * [PR 8173](https://github.com/spyder-ide/spyder/pull/8173) - PR: Fix various DeprecationWarnings and FutureWarnings
  * [PR 8152](https://github.com/spyder-ide/spyder/pull/8152) - PR: Make test_codeanalysis more robust to changes in Pyflakes and Pycodestyle
  * [PR 8133](https://github.com/spyder-ide/spyder/pull/8133) - PR: Skip test_values_dbg in Python 2 because it's timing out too much
  * [PR 8123](https://github.com/spyder-ide/spyder/pull/8123) - PR: Improve usability of runtests locally and test output on the CIs
  * [PR 8116](https://github.com/spyder-ide/spyder/pull/8116) - PR: Do not close split editor when empty or when switching project
  * [PR 8115](https://github.com/spyder-ide/spyder/pull/8115) - PR: Catch errors when trying to replace text in the Editor with a regexp ([7177](https://github.com/spyder-ide/spyder/issues/7177))
  * [PR 8114](https://github.com/spyder-ide/spyder/pull/8114) - PR: Catch errors when trying to display dataframe values as strings ([7195](https://github.com/spyder-ide/spyder/issues/7195))
  * [PR 8111](https://github.com/spyder-ide/spyder/pull/8111) - PR: Remove several old files
  * [PR 8110](https://github.com/spyder-ide/spyder/pull/8110) - PR: Use software OpenGL implementation by default
  * [PR 8048](https://github.com/spyder-ide/spyder/pull/8048) - PR: Don't raise exceptions when writing config to disk fails ([8046](https://github.com/spyder-ide/spyder/issues/8046))
  * [PR 8024](https://github.com/spyder-ide/spyder/pull/8024) - PR: Remove testpath condition now that its conda packages are in good shape
  * [PR 8021](https://github.com/spyder-ide/spyder/pull/8021) - PR: Fix tests by pinning testpath and switching to Python 3.5 on Windows
  * [PR 7928](https://github.com/spyder-ide/spyder/pull/7928) - PR: Update PR template to link to developer COI and clarify other text
  * [PR 7926](https://github.com/spyder-ide/spyder/pull/7926) - PR: Convert and optimize needed PNGs in img_src directory
  * [PR 7908](https://github.com/spyder-ide/spyder/pull/7908) - PR: Fix showing kernel creation error messages
  * [PR 7902](https://github.com/spyder-ide/spyder/pull/7902) - PR: Improve detection of new Spyder versions to be offered for updates ([7862](https://github.com/spyder-ide/spyder/issues/7862))
  * [PR 7898](https://github.com/spyder-ide/spyder/pull/7898) - PR: Clarify and improve Connect to kernel dialog text ([7868](https://github.com/spyder-ide/spyder/issues/7868))
  * [PR 7888](https://github.com/spyder-ide/spyder/pull/7888) - PR: Remove old pdn image source files that are no longer needed
  * [PR 7887](https://github.com/spyder-ide/spyder/pull/7887) - PR: Remove unnecessary code to restart kernels ([7882](https://github.com/spyder-ide/spyder/issues/7882))
  * [PR 7873](https://github.com/spyder-ide/spyder/pull/7873) - PR: Correct next/previous word shortcut callback ([7872](https://github.com/spyder-ide/spyder/issues/7872))
  * [PR 7864](https://github.com/spyder-ide/spyder/pull/7864) - PR: More improvements to Find in Files ([7810](https://github.com/spyder-ide/spyder/issues/7810), [7809](https://github.com/spyder-ide/spyder/issues/7809), [4474](https://github.com/spyder-ide/spyder/issues/4474))
  * [PR 7863](https://github.com/spyder-ide/spyder/pull/7863) - PR: Correctly save Find in Files options when closing Spyder ([6176](https://github.com/spyder-ide/spyder/issues/6176))
  * [PR 7860](https://github.com/spyder-ide/spyder/pull/7860) - PR: Fix failing test due to a new version of nbconvert ([7856](https://github.com/spyder-ide/spyder/issues/7856))
  * [PR 7859](https://github.com/spyder-ide/spyder/pull/7859) - PR: Set selected OpenGL implementation for QtQuick too ([7447](https://github.com/spyder-ide/spyder/issues/7447))
  * [PR 7838](https://github.com/spyder-ide/spyder/pull/7838) - PR: Start testing with Python 3.7 on Linux
  * [PR 7837](https://github.com/spyder-ide/spyder/pull/7837) - PR: Fix tests after ci-helpers updated conda version
  * [PR 7829](https://github.com/spyder-ide/spyder/pull/7829) - PR: Use a function to create and get our temporary directory ([7800](https://github.com/spyder-ide/spyder/issues/7800))
  * [PR 7817](https://github.com/spyder-ide/spyder/pull/7817) - PR: Don't import objects in collectionseditor that are not dicts ([7244](https://github.com/spyder-ide/spyder/issues/7244))
  * [PR 7816](https://github.com/spyder-ide/spyder/pull/7816) - PR: Don't ignore all files when exclude pattern is empty ([7811](https://github.com/spyder-ide/spyder/issues/7811))
  * [PR 7812](https://github.com/spyder-ide/spyder/pull/7812) - PR: Truncate results correctly in Find in Files for Python 2 ([6218](https://github.com/spyder-ide/spyder/issues/6218))
  * [PR 7807](https://github.com/spyder-ide/spyder/pull/7807) - PR: Correctly handling pydoc._start_server on Python 3.7 ([7721](https://github.com/spyder-ide/spyder/issues/7721))
  * [PR 7806](https://github.com/spyder-ide/spyder/pull/7806) - PR: Stop searches in Find in Files correctly and improve how to exclude file types ([7804](https://github.com/spyder-ide/spyder/issues/7804), [7803](https://github.com/spyder-ide/spyder/issues/7803))
  * [PR 7791](https://github.com/spyder-ide/spyder/pull/7791) - PR: Remove gettext scripts separated into their own repo
  * [PR 7790](https://github.com/spyder-ide/spyder/pull/7790) - PR: Protect calls to unregister_editorstack_cb and pin sip in our tests
  * [PR 7785](https://github.com/spyder-ide/spyder/pull/7785) - PR: House cleaning
  * [PR 7769](https://github.com/spyder-ide/spyder/pull/7769) - PR: Exclude non-runnable code from coverage reports
  * [PR 7766](https://github.com/spyder-ide/spyder/pull/7766) - PR: Fix Browse and Commit vcs actions in file and project explorers ([7733](https://github.com/spyder-ide/spyder/issues/7733))
  * [PR 7765](https://github.com/spyder-ide/spyder/pull/7765) - PR: Fix minor issues with the tutorial as pointed out by Dr. Fangohr himself
  * [PR 7764](https://github.com/spyder-ide/spyder/pull/7764) - PR: Catch error when dropping a file on the Editor doesn't have an associated url ([7742](https://github.com/spyder-ide/spyder/issues/7742))
  * [PR 7761](https://github.com/spyder-ide/spyder/pull/7761) - PR: Catch errors generated when creating the env vars dialog  ([7748](https://github.com/spyder-ide/spyder/issues/7748))
  * [PR 7759](https://github.com/spyder-ide/spyder/pull/7759) - PR: Catch any error when trying to copy the contents of a dataframe ([7753](https://github.com/spyder-ide/spyder/issues/7753))
  * [PR 7727](https://github.com/spyder-ide/spyder/pull/7727) - PR: Make the text of the About Spyder message box selectable ([6535](https://github.com/spyder-ide/spyder/issues/6535))
  * [PR 7720](https://github.com/spyder-ide/spyder/pull/7720) - PR: Implement a workaround to toggle on/off fullscreen mode for Windows systems ([4291](https://github.com/spyder-ide/spyder/issues/4291))
  * [PR 7717](https://github.com/spyder-ide/spyder/pull/7717) - PR: Catch any error generated when trying to start kernels ([7302](https://github.com/spyder-ide/spyder/issues/7302))
  * [PR 7716](https://github.com/spyder-ide/spyder/pull/7716) - PR: Catch error when writing to stdin and there's no kernel client available ([7578](https://github.com/spyder-ide/spyder/issues/7578))
  * [PR 7715](https://github.com/spyder-ide/spyder/pull/7715) - PR: Simplify how custom interpreters are loaded/saved ([7674](https://github.com/spyder-ide/spyder/issues/7674))
  * [PR 7712](https://github.com/spyder-ide/spyder/pull/7712) - PR: Catch errors when getting file type extensions supported by Pygments ([7705](https://github.com/spyder-ide/spyder/issues/7705))
  * [PR 7700](https://github.com/spyder-ide/spyder/pull/7700) - PR: Add option to select OpenGL implementation used by Qt
  * [PR 7694](https://github.com/spyder-ide/spyder/pull/7694) - PR: Make "Are you sure you want to restart the kernel?" warning optional ([7561](https://github.com/spyder-ide/spyder/issues/7561))
  * [PR 7691](https://github.com/spyder-ide/spyder/pull/7691) - PR: Load css when showing kernel errors in the IPython console
  * [PR 7679](https://github.com/spyder-ide/spyder/pull/7679) - PR: Make editor for collection types which copy incorrectly read-only ([6936](https://github.com/spyder-ide/spyder/issues/6936))
  * [PR 7655](https://github.com/spyder-ide/spyder/pull/7655) - PR: Add validation in Python 2 to prevent the addition of paths with unicode characters to the PYTHONPATH ([7236](https://github.com/spyder-ide/spyder/issues/7236))
  * [PR 7205](https://github.com/spyder-ide/spyder/pull/7205) - PR: Unmaximize plugins when an action or menu calls another plugin ([937](https://github.com/spyder-ide/spyder/issues/937))
  * [PR 4473](https://github.com/spyder-ide/spyder/pull/4473) - PR: Add Hungarian translation
* Thu Aug 16 2018 jengelh@inai.de
- Ensure neutrality of description and trim filler words.
* Mon Aug 13 2018 toddrme2178@gmail.com
- Update to Version 3.3.1
  + New features
    > Preferences
  * Save the list of custom interpreters introduced in
    `Preferences > Python interpreter`.
    > IPython console
  * Do not save pdb commands in debugging history
  + Issues Closed
  * Tutorial should be conformed to the Spyder Docs style guide ([PR 7659](https://github.com/spyder-ide/spyder/pull/7659))
  * Tutorial is out of date and needs updating ([PR 7643](https://github.com/spyder-ide/spyder/pull/7643))
  * Include runtests.py in tarball ([PR 7651](https://github.com/spyder-ide/spyder/pull/7651))
  * Update setup.py with polished, up to date description, links and metadata for PyPI ([PR 7582](https://github.com/spyder-ide/spyder/pull/7582))
  * Improve selection of custom Python interpreter in Preferences ([PR 7566](https://github.com/spyder-ide/spyder/pull/7566))
  * IOError when getting saved file names in a project ([PR 7515](https://github.com/spyder-ide/spyder/pull/7515))
  * NameError: name '_' is not defined ([PR 7495](https://github.com/spyder-ide/spyder/pull/7495))
  * "switch to console" keyboard shortcut doesn't do anything ([PR 7471](https://github.com/spyder-ide/spyder/pull/7471))
  * Check for new conda packages in Anaconda's repos instead of Github ([PR 7478](https://github.com/spyder-ide/spyder/pull/7478))
  * Error in display of tabulator in editor ([PR 7464](https://github.com/spyder-ide/spyder/pull/7464))
  * Don't ask again ineffective in Console delete all variables dialog  ([PR 7462](https://github.com/spyder-ide/spyder/pull/7462))
  * AttributeError: 'NoneType' object has no attribute 'get_active_project_path' ([PR 7409](https://github.com/spyder-ide/spyder/pull/7409))
  * Update readme and contributing guide to reflect need to install (correct version of) spyder-kernels ([PR 7418](https://github.com/spyder-ide/spyder/pull/7418))
  * Failure checking out a branch and the opened file is in a different path ([PR 7642](https://github.com/spyder-ide/spyder/pull/7642))
  * Syntax highlighting for numeric literals containing underscores ([PR 7505](https://github.com/spyder-ide/spyder/pull/7505))
  * Debugging history saves both python commands and pdb commands ([PR 7300](https://github.com/spyder-ide/spyder/pull/7300))
  * Error when connecting to external kernels ([PR 7463](https://github.com/spyder-ide/spyder/pull/7463))
  * Do not reopen Project explorer on startup ([PR 7546](https://github.com/spyder-ide/spyder/pull/7546))
  * Spyder hangs on interactive input in internal console (input is not redirected) ([PR 7500](https://github.com/spyder-ide/spyder/pull/7500))
  + Pull Requests Merged
  * Conform tutorial to docs style guide and further minor improvements ([7652](https://github.com/spyder-ide/spyder/issues/7652))
  * Add runtests.py and conftest.py to our tarball ([7639](https://github.com/spyder-ide/spyder/issues/7639))
  * Don't require keyring for Python 2 and Linux in our wheels
  * Edit tutorial to update it, fix errors, copyedit and clarify ([7641](https://github.com/spyder-ide/spyder/issues/7641))
  * Handle error when doing a browser history update ([7328](https://github.com/spyder-ide/spyder/issues/7328))
  * Upgrade all links to use HTTPS where available, and fix link targets when broken/redirected
  * Update conda install command for spyder-kernels 1.x
  * Fix bug in spyder3.appdata.xml
  * Send reported issues to Spyder's main repo in DEV mode
  * Update capitalization of Spyder name, and standardize description with everywhere else
  * Update setup.py description, metadata, links, and more ([7581](https://github.com/spyder-ide/spyder/issues/7581))
  * Improve selection of custom interpreter ([7529](https://github.com/spyder-ide/spyder/issues/7529))
  * Migrate to CircleCI 2.0
  * Do not automatically open Project Explorer when opening project if user closed it ([6292](https://github.com/spyder-ide/spyder/issues/6292))
  * Fix misspelling in Japanese translation
  * Catch errors when saving/getting the list of open files per project ([7513](https://github.com/spyder-ide/spyder/issues/7513))
  * Add support for numeric literals with underscores highlighting in Python 3.6 ([7324](https://github.com/spyder-ide/spyder/issues/7324))
  * Setting tab stop width by using the width of multiple spaces ([7432](https://github.com/spyder-ide/spyder/issues/7432))
  * Handle input commands correctly in the internal console. ([1329](https://github.com/spyder-ide/spyder/issues/1329))
  * Reinstall Matplotlib in Appveyor in case it had been removed
  * Avoid raising an error when getting available translations ([7489](https://github.com/spyder-ide/spyder/issues/7489))
  * Change way to check for updates ([7452](https://github.com/spyder-ide/spyder/issues/7452))
  * Remove old shortcut for the Python console ([7465](https://github.com/spyder-ide/spyder/issues/7465))
  * Fix tabulation spacing by setting tab spacing after the font ([7432](https://github.com/spyder-ide/spyder/issues/7432))
  * Fix connection to external kernels ([7082](https://github.com/spyder-ide/spyder/issues/7082))
  * Really hide reset namespace warning in IPython console ([7404](https://github.com/spyder-ide/spyder/issues/7404))
  * Improve message about the lack of spyder-kernels in external interpreters
  * Update the running Github clone procedure in the readme and contributing guide to include spyder-kernels ([7337](https://github.com/spyder-ide/spyder/issues/7337))
  * Catch AttributeError when trying to get the active project path ([7403](https://github.com/spyder-ide/spyder/issues/7403))
  * Remove conda recipe
  * Do not save pdb commands in debugging history ([7299](https://github.com/spyder-ide/spyder/issues/7299))
- Update to Version 3.3
  + New features
    > Main Window
  * Add a new error reporting dialog to simplify and automate the process of
    submitting reports to Github.
    > IPython console
  * Add an option to use a tight layout with inline plots. Activate it under
    `Preferences > IPython console > Graphics`.
  * Add an option to turn on/off Jedi completions. Activate it under
    `Preferences > IPython console > Advanced`.
    > Variable Explorer
  * Change the button names of all its viewers from `Ok` and `Cancel` to
    `Save and Close` and `Close`, respectively, to better express what each
    one really does.
  * Fix several critical memory leaks.
    > Under the hood
  * Remove support for PyQt 5.4 and older versions.
  * Remove support for PyQt4.
  * Remove support for Python 3.3.
  * Move all code used to create kernels for our consoles to a new package
    called `spyder-kernels`. It's required version for Spyder 3.3+ is any
    `0.x.x` release (e.g `0.2.3`).
  * Add the `keyring` package as a new dependency to safely save users
    Github passwords.
  + Issues Closed
  * Update translations for 3.3.0
  * Spyder (Python 3.6) + Pandas 0.23 - Future Warning ([PR 7335](https://github.com/spyder-ide/spyder/pull/7335))
  * HIstory browsing while debugging is broken ([PR 7296](https://github.com/spyder-ide/spyder/pull/7296))
  * "Stop the current command" stops only the first run after "Run file" button is pressed more than one time ([PR 7294](https://github.com/spyder-ide/spyder/pull/7294))
  * ImportError when trying to load third-party plugins ([PR 7263](https://github.com/spyder-ide/spyder/pull/7263))
  * Add pythoncom and fastmat to the UMR blacklist ([PR 7198](https://github.com/spyder-ide/spyder/pull/7198))
  * "SyntaxError: invalid syntax" when creating kernel manager ([PR 7163](https://github.com/spyder-ide/spyder/pull/7163))
  * Validate serialized length of modified objects in the Variable Explorer ([PR 7218](https://github.com/spyder-ide/spyder/pull/7218))
  * Ensure garbage collection is run in the main window when closing Variable Explorer editors ([PR 7234](https://github.com/spyder-ide/spyder/pull/7234))
  * Change behavior of the Variable Explorer editors buttons ([PR 7202](https://github.com/spyder-ide/spyder/pull/7202))
  * Don't save IPython history in safe mode ([PR 7151](https://github.com/spyder-ide/spyder/pull/7151))
  * Error when getting Pygments lexers ([PR 7150](https://github.com/spyder-ide/spyder/pull/7150))
  * Running ./bootstap.py --test should open an empty history.py ([PR 7115](https://github.com/spyder-ide/spyder/pull/7115))
  * "Help > Report Issue" goes to a broken link if not logged into GitHub ([PR 7230](https://github.com/spyder-ide/spyder/pull/7230))
  * typo in locale\fr ([PR 7160](https://github.com/spyder-ide/spyder/pull/7160))
  * Spyder is slow to start due to big history file ([PR 7132](https://github.com/spyder-ide/spyder/pull/7132))
  * RuntimeWarning when displaying min/max in the Variable Explorer ([PR 7154](https://github.com/spyder-ide/spyder/pull/7154))
  * Can't use pythonw as interpreter when needed on Mac ([PR 7170](https://github.com/spyder-ide/spyder/pull/7170))
  * ValueError: unknown locale when starting kernels ([PR 7159](https://github.com/spyder-ide/spyder/pull/7159))
  * Multiple loading of pytorch module with script causes RuntimeError on IPython console. ([PR 7168](https://github.com/spyder-ide/spyder/pull/7168))
  * Error when setting color scheme in the IPython console ([PR 7164](https://github.com/spyder-ide/spyder/pull/7164))
  * AttributeError: Nonetype has no attribute "clear" when right clicking in the empty project explorer with no project open ([PR 7165](https://github.com/spyder-ide/spyder/pull/7165))
  * Realtime code analysis stops working when non-ASCII characters are used in strings ([PR 7254](https://github.com/spyder-ide/spyder/pull/7254))
  * Spyder crashes with segmentation fault on startup in Anaconda 4.5.0 ([PR 7029](https://github.com/spyder-ide/spyder/pull/7029))
  * Add Astropy to default UMR blacklist for Python 2.7 due to resulting bug ([PR 7168](https://github.com/spyder-ide/spyder/pull/7168))
  * Error when viewing bytes in the Variable Explorer ([PR 7206](https://github.com/spyder-ide/spyder/pull/7206))
  * OSError: [Errno 28] No space left on device ([PR 7210](https://github.com/spyder-ide/spyder/pull/7210))
  * Spyder opens new instances when double-clicking Python scripts ([PR 7260](https://github.com/spyder-ide/spyder/pull/7260))
  * Remove support for PyQt4 ([PR 6961](https://github.com/spyder-ide/spyder/pull/6961))
  * Include Matplotlib in Help > Dependencies ([PR 7166](https://github.com/spyder-ide/spyder/pull/7166))
  * Spyder fails to start when trying to set language on Windows ([PR 7159](https://github.com/spyder-ide/spyder/pull/7159))
  * UnicodeEncodeError when saving Help's history ([PR 7246](https://github.com/spyder-ide/spyder/pull/7246))
  * Script executes in other console of its dedicated console is dedicated is on debugging ([PR 7243](https://github.com/spyder-ide/spyder/pull/7243))
  * The tab switcher widget won't close if it loses focus ([PR 6759](https://github.com/spyder-ide/spyder/pull/6759))
  * Find Russian symbols with a regexp gives an error ([PR 7209](https://github.com/spyder-ide/spyder/pull/7209))
  * Cannot runfile if the name of the file contains a `'` character in Windows
  * TypeError: unsupported operand type(s) for -: 'float' and 'NoneType' ([PR 6769](https://github.com/spyder-ide/spyder/pull/6769))
  * 'Execute in an external system terminal' doesn't work if there is spaces in the path where the python interpreter is installed in Windows ([PR 6750](https://github.com/spyder-ide/spyder/pull/6750))
  * Changing file in editor with [Ctl]+[tab] uncompatible with tiling window manager ([PR 6759](https://github.com/spyder-ide/spyder/pull/6759))
  * The figure layout is not respected when plotting inline in the IPython console ([PR 6790](https://github.com/spyder-ide/spyder/pull/6790))
  * Use an authentication dialog to send reports to Github ([PR 6707](https://github.com/spyder-ide/spyder/pull/6707))
  * Errors when selecting a kernel from a different Python installation ([PR 7306](https://github.com/spyder-ide/spyder/pull/7306))
  * No such file or directory when trying to access %%userprofile ([PR 7287](https://github.com/spyder-ide/spyder/pull/7287))
  * Plotting with Mayavi is broken ([PR 6919](https://github.com/spyder-ide/spyder/pull/6919))
  * Avoid showing autoreload warnings ([PR 7306](https://github.com/spyder-ide/spyder/pull/7306))
  * Error trying to open renamed project ([PR 7272](https://github.com/spyder-ide/spyder/pull/7272))
  * Move online documentation to Github Pages ([PR 7007](https://github.com/spyder-ide/spyder/pull/7007))
  * Stop button not working after second run on dedicated consoles ([PR 7245](https://github.com/spyder-ide/spyder/pull/7245))
  * UnicodeDecodeError thrown when viewing Dataframes with non-ascii index ([PR 7242](https://github.com/spyder-ide/spyder/pull/7242))
  * Variable Explorer is leaking memory when editing variables ([PR 7234](https://github.com/spyder-ide/spyder/pull/7234))
  * Adding, removing, or moving a breakpoint while debugging changes the focus ([PR 7251](https://github.com/spyder-ide/spyder/pull/7251))
  + Pull Requests Merged
  * Update Spanish translation for 3.3
  * Update Brazilian Portuguese translation for 3.3
  * French translation for 3.3
  * Update Japanese translation for 3.3
  * Handle deprecated Pandas methods in tests ([7312](https://github.com/spyder-ide/spyder/issues/7312))
  * Move all kernel code to an external package called spyder-kernels ([6469](https://github.com/spyder-ide/spyder/issues/6469), [6297](https://github.com/spyder-ide/spyder/issues/6297))
  * Fix history browsing while debugging ([7295](https://github.com/spyder-ide/spyder/issues/7295))
  * Don't allow multiple executions in the IPython console when one is taking place ([7293](https://github.com/spyder-ide/spyder/issues/7293))
  * Improve detection of users' home directory ([6351](https://github.com/spyder-ide/spyder/issues/6351))
  * Fix crash while running our tests on CircleCI
  * Fix links to Travis CI and Google Group
  * Add validation when renaming the active project outside Spyder ([6036](https://github.com/spyder-ide/spyder/issues/6036))
  * Catch any error when trying to load third-party plugins ([7259](https://github.com/spyder-ide/spyder/issues/7259))
  * Add spyder-script.py as a valid name to be detected by lockfile ([6899](https://github.com/spyder-ide/spyder/issues/6899))
  * Prevent realtime code analysis failures due to encoding errors ([6970](https://github.com/spyder-ide/spyder/issues/6970))
  * Stop editor from jumping around when adding/removing lines with breakpoints while debugging ([5201](https://github.com/spyder-ide/spyder/issues/5201))
  * Save credentials in the Github login dialog
  * Catch possible errors when writing Help's history to disk ([6864](https://github.com/spyder-ide/spyder/issues/6864))
  * Avoid disabling consoles stop button when an execution is taking place ([5958](https://github.com/spyder-ide/spyder/issues/5958))
  * Show message in our consoles when trying to run a file while on debugging ([6851](https://github.com/spyder-ide/spyder/issues/6851))
  * Fix error when viewing dataframe with a non-ascii index ([5833](https://github.com/spyder-ide/spyder/issues/5833))
  * Improve pythonw detection
  * Call garbage collector from Main Window after closing Variable Explorer editors ([7157](https://github.com/spyder-ide/spyder/issues/7157), [5830](https://github.com/spyder-ide/spyder/issues/5830))
  * Run tests in macOS
  * Use the error dialog to report issues too ([7101](https://github.com/spyder-ide/spyder/issues/7101))
  * Limit length of serialized values in Variable Explorer when applying modifications ([7158](https://github.com/spyder-ide/spyder/issues/7158))
  * Catch EnvironmentError in all places we write to disk ([6901](https://github.com/spyder-ide/spyder/issues/6901))
  * Fix error when using unicode to search text with regular expressions in the Editor ([6812](https://github.com/spyder-ide/spyder/issues/6812))
  * Add bytes or unicode ellipses in value_to_display ([6942](https://github.com/spyder-ide/spyder/issues/6942))
  * Change behavior of Variable Explorer editor buttons ([7156](https://github.com/spyder-ide/spyder/issues/7156))
  * Add fastmat and pythoncom to UMR blacklist. ([7190](https://github.com/spyder-ide/spyder/issues/7190))
  * Add env var to prevent showing useless warning in macOS
  * Change validation to allow pythonw executables as valid interpreters ([7059](https://github.com/spyder-ide/spyder/issues/7059))
  * Remove internal copy of our docs
  * Add astropy and pythorch to UMR blacklist by default. ([7041](https://github.com/spyder-ide/spyder/issues/7041), [6962](https://github.com/spyder-ide/spyder/issues/6962))
  * Add Matplotlib as optional dependency for the IPython Console. ([6887](https://github.com/spyder-ide/spyder/issues/6887))
  * Handle not initialized menu in DirView. ([6975](https://github.com/spyder-ide/spyder/issues/6975))
  * Handle AttributeError when setting color scheme in the IPython Console. ([6996](https://github.com/spyder-ide/spyder/issues/6996))
  * Show errors generated when creating QtKernelManager inside the IPython console ([7161](https://github.com/spyder-ide/spyder/issues/7161))
  * Fix typo in 'Save File' french translation. ([7100](https://github.com/spyder-ide/spyder/issues/7100))
  * Fix a couple of problems when setting and detecting the system locale ([7051](https://github.com/spyder-ide/spyder/issues/7051), [6886](https://github.com/spyder-ide/spyder/issues/6886))
  * Filter a Numpy 1.14 warning shown in our consoles ([7063](https://github.com/spyder-ide/spyder/issues/7063))
  * Avoid loading/saving IPython console history in safe mode or testing ([7149](https://github.com/spyder-ide/spyder/issues/7149))
  * Catch any exception when trying to get Pygments lexers ([7148](https://github.com/spyder-ide/spyder/issues/7148))
  * Limit the number of lines in history according to the relevant setting ([7080](https://github.com/spyder-ide/spyder/issues/7080))
  * Add --safe-mode option to start with a clean config directory ([7112](https://github.com/spyder-ide/spyder/issues/7112))
  * Add Twitter and Facebook links to Readme, for SEO/visibility
  * Remove Jedi pinnings in our CIs
  * Load libGL using low-level function without requiring pyopengl ([6968](https://github.com/spyder-ide/spyder/issues/6968))
  * Update links to docs when they are ready  ([5986](https://github.com/spyder-ide/spyder/issues/5986))
  * Adapt sphinxify for changes in Sphinx 1.8
  * Skip tests numpy_returns and matplotlib_figure_returns for now on jedi >=0.12 and pin CIs to 0.11.1
  * Update minimum Python version in setup.py to 3.4
  * Add a few extra badges, fix troubleshooting link in readme and update banner
  * Remove support for PyQt4 ([6889](https://github.com/spyder-ide/spyder/issues/6889))
  * Check "use a tight layout for inline plots" by default in the preferences
  * Update contributing doc with better organization, standard links and minor fixes
  * Fix often failing elapsed time test with fuzzier check and more reps
  * Fix tests after update to PyQt 5.9
  * Fix Mayavi plotting in our consoles ([6339](https://github.com/spyder-ide/spyder/issues/6339))
  * Update readme screenshot, streamline organization, add banner and update/cleanup content
  * Bump next version to be 3.3.0
  * Add checklists for Github issue report and pull requests
  * Remove old code present in our kernel
  * Add option to use Jedi in the IPython console + warning on greedy completer
  * Add instance pattern "cls" for class methods
  * Add an option to control bbox_inches option when plotting inline ([6619](https://github.com/spyder-ide/spyder/issues/6619))
  * Fix a bug when running a file with a single quote character in its name
  * Initialize start time to a time and not None ([6767](https://github.com/spyder-ide/spyder/issues/6767))
  * Add 3.2.8 version header to the changelog
  * Change Editor's tab switcher from Qt.SubWindow to Qt.Popup for tiling window managers ([6834](https://github.com/spyder-ide/spyder/issues/6834), [6743](https://github.com/spyder-ide/spyder/issues/6743))
  * Enclose python exe path in double quotes ([6746](https://github.com/spyder-ide/spyder/issues/6746))
  * Add authentication dialog to submit issues to Github ([6617](https://github.com/spyder-ide/spyder/issues/6617))
* Fri Jun  1 2018 sebix+novell.com@sebix.at
- add dependency python3-cloudpickle, fixes boo#1095587
- user %%license macro
* Sat Apr 28 2018 toddrme2178@gmail.com
- Update to Version 3.2.8
  + New features
    > Editor
  * Add `Ctrl+Shift+Enter` shortcut to introduce new lines at any point.
    > IPython console
  * Always run Cython files in a dedicated console.
  + Issues Closed
  * ValueError trying to open pandas.DateOffset objects in Variable Explorer
  * AttributeError when attempting to edit non-writeable or non-settable attributes of certain (e.g. many common Pandas) objects in CollectionsEditor
  * TypeError and Python hard crash to desktop after modifying _typ attribute of pandas Period in CollectionsEditor
  * Saving session data (spydata) deletes all arrays nested inside other data structures
  * System time change causes Spyder error
  * AttributeError: 'NoneType' object has no attribute 'apply_plugin_settings' when attempting to activate Automatic Connections for Help
  * Typo in introspection.utils.get_words
  * Sphinx html_use_smartypants is deprecated as of 1.6 and removed in 1.7
  * Spyder always open a new instance after updating to 3.2.7 version
  * Strange behavior for Spyder code annotations
  * AttributeError: 'NoneType' object has no attribute 'apply_plugin_settings'
  * AttributeError: 'NoneType' object has no attribute 'load_module'
  * Setting a path containing a single quote
  * ValueError when closing a file whose folder changed name in File Explorer
  * When browsing MultiIndex in Object Explorer, Pandas raises NotImplementedError: isna is not defined for MultiIndex
  * FileNotFoundError generated for template.py
  * Variable Explorer windows don't close when Spyder exits; prevents it from reopening until manually closed
  * Bug: Find and Replace indicate "no matches" when "[", "(", or ")" included in the search string
  * AttributeError when attempting to view dom.minidom.Element object in Variable Explorer
  * How do I move to a new line while I'm in the middle of the current line?
  * pyximport.install() in sitecustomize.py is not a good idea
  * delete (context="editor", name="delete") keyboard shortcut doesn't work
  * Saving large workspace on network drive crashes Spyder on Windows
  + Pull Requests Merged
  * Error report stopgap to make instructions harder to miss
  * Fix various bugs in Variable Explorer, including an application crash to desktop
  * Replace deprecated function in inline CollectionsEditor tests and add recently supported data types
  * Make several GUI/qtbot tests more reliable by increasing timeouts and tweaking the methods used
  * Add .pytest_cache to gitignore
  * Fix new instance validation on Windows.
  * Fix NotImplementedError when browsing a MultiIndex in the Collection Editor
  * Set parent for Variable Explorer editors so Spyder closes properly
  * Change time elapsed calculation to prevent OSError
  * Fix bugs in session saving to spydata and improve tests
  * Allow TODO check marks with blank line
  * Fix typo in utils.introspection.get_words
  * Pin to a Tornado version less than 5.0 to avoid hangs in our tests
  * Run Cython files in a dedicated console
  * Avoid showing dialogs in IPython console tests to avoid segfaults
  * Be able to open files in the Editor if no template is found
  * Add handling for AttributteError when importing module from path
  * Remove ipyconsole and editor attrs from the Help plugin
  * Update deprecated Sphinx directive html_use_smartypants
  * Allow rename from Explorer to work for directories
  * Fix error when setting a path with a single quote
  * Delay check whether we are running under pytest until run time
  * Allow shortcut key for editor/delete to work like Del key
  * Restore the previous wording for package versions in error report
  * Skip some IPython console tests in PyQt4 because they are segfaulting too much
  * Find/replace - return match counts on unescaped characters
  * Add Ctrl+Shift+Enter to enter a new line in the Editor
- Update to Version 3.2.7
  + New features
    > Main Window
  * Improve the interface to report errors to Github.
    > Variable Explorer
  * Enable the display of many more Numpy array types.
    > Editor
  * Copy text from the search field to the replace one
    after pressing `Tab`.
    > IPython console
  * Make `%%edit foo.py` open `foo.py` in the Editor on
    Windows.
    > Find in Files
  * Remove items from the `Search in` list when hovering
    over them and pressing `Del`.
  * Add a `Clear this list` option below `Select other
    directory`.
    > Under the hood
  * Demand PyQt less than 5.10 for our wheels.
  + Issues Closed
  * Update translations for 3.2.7
  * test_completions_custom_path fails with jedi 0.9.0 (Spyder 3)
  * FileNotFoundError history.py when running code in the IPython console
  * Mouse cursor issue with PyQt 5.10
  * Add the the Collapse All and Expand All buttons to the toolbar of the Outline Explorer
  * PermissionError when Spyder is started
  * Selecting "tutorial" from help menu does not bring up Help pane automatically if not loaded, leading to user confusion
  * IndexError when getting help of an object
  * AttributeError when running code in the IPython console
  * RuntimeError when interrupting kernel
  * pdb history doesn't collapse similar text
  * IOError when trying to write to stderr file
  * Convert re expressions to use raw strings
  * Errors pop up when change the key shortcuts in python 2.7
  * %%edit magic command does not work on Windows
  * Color scheme changes after kernel restart
  * Spyder Profiler Hangs/Freezes
  * Bug with saved window layouts
  * Icon should be moved from share/pixmaps to share/icons
  * UnicodeEncodeError when searching text in the Editor
  * Uncaught error when opening a pandas DataFrame with out of bounds timestamps
  * Several tests fail locally under user environment with customized keyboard shortcuts due to relying on hardcoded keybindings
  * TypeError: tabText(self, int) when moving plugin tabs
  * UnicodeEncodeError when using a project with non-ascii characters on it
  * UnicodeDecodeError when moving a file with Project Explorer
  * Add missing Keywords metadata in desktop file
  * Paths in the "Search in" combobox of the "Find in File" plugin becomes corrupted
  * Improve interface to report errors
  * IPython console failing when custom interpreter is removed
  * Use Tab key to copy text to "Replace with:" field
  + Pull Requests Merged
  * Update Spanish translation
  * French translation for 3.2.7
  * Update Japanese translation for 3.2.7
  * Update Brazilian Portuguese translation
  * Update Russian translation
  * Demand PyQt5 less than 5.10 in our wheels
  * Skip test_completions_custom_path if jedi version before 0.10.0
  * Update broken matplotlib project URL in install doc
  * Make projects work on unicode directories
  * Handle errors when writing history to disk in the IPython Console
  * Fix all test files to be run independently
  * Xfail test_auto_backend for certain versions of zmq and ipykernel
  * Add test for file directory change in the Project Explorer.
  * Add keywords to desktop files
  * Change share/pixmaps to share/icons in setup.py
  * Add error handling for the lockfile symlink on Windows
  * Harmonized the toolbar of the Outline Explorer with its context menu.
  * Add validation for custom interpreter option
  * Show Help if closed when opening tutorial to avoid user confusion
  * Fix and catch typeerror thrown when from_index is None while moving plugin tab
  * Catch any error in the isdefined method of dochelpers
  * Handle AttributeError when running code in the IPython Console.
  * Catch any error when creating stderr files in the IPython console
  * Catch RuntimeError when no kernel is running
  * Skip test_tab_copies_find_to_replace on Linux because it fails
  * Don't add repeated entries to history while on pdb
  * Skip test_calltip on Python 3 and PyQt < 5.9 because it's failing there
  * Custom layouts not working when hexstate is None
  * Pin pyqt5 to 5.9.2 on tests because 5.10 is giving segfaults during the collection phase
  * Install and run window manager in Travis to fix focus issues and unskip now-passing tests
  * Update Brazilian Portuguese translation
  * Change to re strings for Deprecation Warning
  * Use a temporary config directory to run our tests
  * Preserve color scheme on kernel restart
  * Update super() call to use Python 2 style call
  * Fix %%edit magic on Windows
  * Fix Profiler error when run is stopped
  * Catch OutOfBoundsDatetime errors from pandas
  * Use a checkbox in error dialog to dismiss it instead of a button
  * Fix some completion errors in the Editor and show again no docs message in Help
  * Fix error when searching text in the Editor in translated interfaces
  * Find/replace - Copy search text to replace textbox on tabbing between them
  * Add troubleshooting blurb and OS version to issue template and enhance UI
  * Add Troubleshooting links and blurb to various appropriate places in Spyder and doc
  * Enable the display of many more numpy array types in the Variable Explorer
  * Fix 3 bugs and add 4 improvements to Find in Files
  * Major overhaul of Readme, contributing and install docs
  * Differenciate between ), }, and ] when closing brackets
  * Change error report dialog to enter issue description before submitting it
- Update to Version 3.2.6
  + New features
    > Editor
  * Make `Shift+Del` to cut text if users have some text
    selected.
  * Make `Shift+Ins` to paste text.
  * Make `Ctrl+PgUp`, `Ctrl+PgDn` and `Ctrl+Tab` shortcuts
    configurable.
    > Variable Explorer
  * Display date/times in human readable format.
  * Disable editing for immutable types (e.g. tuples).
    > Under the hood
  * Fix installation of wheels with `pip`.
  + Issues Closed
  * Error on Maximize Current Pane
  * AttributeError when resetting console namespace
  * Not able to change layouts after resetting
  * DataFrame Editor raises TypeError when editing any complex type
  * Fix errors when entering a value for a cell larger than the max int in Array and Dataframe editors
  * Consoles get renamed when moved in the IPython console
  * 3.2.5 fails to activate Matplotlib Qt5 backend
  * Variable Explorer throws an error instead of displaying contents when attempting to inspect any loaded modules
  * Spyder not starting in macOS because pyopengl is present
  * Update to 3.2.5 with pip fails for Python 2.7 as it pulls pyqt5
  * Spyder crashes upon typing `net(` in editor
  * When comparing a generated and loaded profile, any negative deltas show (actual_value - ?) 1h:60min, not actual value
  * Improve how we detect that Spyder is running under Anaconda
  * Shift+del should delete line only when empty selection, otherwise clipboard cut
  * Tuples can be "edited" in Variable Explorer but changes are discarded
  * "ValueError: malformed node or string" when evaluating code that contains Path elements
  * Window layout setting error
  * Segmentation fault when trying to change keyboard shortcuts in Preferences
  * File switcher error
  * ValueError: not enough values to unpack in the File Explorer
  * Add ability to change Ctrl+PgUp and PgDn shortcuts
  * Keyboard shortcut hint is missing from menu item Search/Find in files
  * Tab in-between find and replace text boxes
  + Pull Requests Merged
  * Fix error when trying to maximize plugins that don't have a dock widget
  * Catch error when resetting console namespace and no kernel_client is available
  * Skip some tests because they are failing locally or segfaulting
  * Cannot change windows layout on first start after reset
  * Add shortcut to Find in Files in Search menu
  * Mark introspection test slow and re-enable it on certain CIs
  * Add test to verify that the Automatic backend is working correctly
  * Run slow tests only in our CIs
  * Fix TypeError editing any complex val in DataFrameEditor, and bug resulting in bool_s being treated as uneditable
  * Prevent an error in the FileSwitcher when all tabs are closed in the last focused widget.
  * Allow tab cycling shortcuts to be configurable in Editor
  * Patch ipykernel to avoid errors when setting the Qt5 Matplotlib backend
  * Fix crash and error dialog when triggering OverflowError (too large int) when editing arrays and dataframes
  * Fix renames when moving IPython console tabs
  * Fix negative deltas on profiler
  * Avoid a calltip crash when docstring is None
  * Fix mime type error detection in the File Explorer
  * Remove unnecessary flaky from introspection test, minor cleanup
  * Make Tab key properly switch between find and replace fields
  * Fix segfault on shortcut preferences when using mouse
  * Improve how we detect if we are running under Anaconda
  * Avoid errors when importing pyopengl at startup
  * Make pyqt5 a wheel dependency only for Python 3
  * Fix error when attempting to view module contents in CollectionsEditor
  * Add expected default behavior for Shift+Del and Shift+Ins
  * Add coverage files and Notepad++ backups to gitignore
  * Skip several failing tests on Windows and one on a specific CI build
  * Add test coverage reporting with AppVeyor to Codecov
  * Display date/times in human readable format in Variable Explorer
  * Make bullets/numbers/headings more consistent and add Anaconda for Linux in install doc
  * Properly disable editing in Variable Explorer for values in immutable collections (e.g. tuples)
  * Manage types that extend str in value_to_display
- Update to Version 3.2.5
  + New features
    > IPython Console
  * Improve kernel startup time.
  * Add option to show kernel elapsed time.
  * Add button and option to remove all user-defined variables.
  * Load `%%autoreload` magic at kernel startup to make changes to
    modules take effect instantly in the console.
  * Use `cloudpickle` to serialize/deserialize data between kernels
    and Spyder.
    > Variable Explorer
  * Add support for `datetime.timedelta` objects.
    > Under the hood
  * Add `pyqt5` as a new wheel dependency.
  * Add a new `--hide-console` option and deprecate `--show-console`
    on Windows.
  + Issues Closed
  * Update translations for 3.2.5
  * Remove 'DMG Installers' option from documentation
  * UserWarning: Config option use_jedi not recognized by IPCompleter
  * Error when choosing rename option after editing tuple value from Variable explorer.
  * Code from one file not updating when called from another if run directly in the console
  * "Real-time code style analysis" checkbox in Prefs > Editor > Introspection checks for pep8, not pycodestyle
  * Return value of EditorStack.has_filename not checked properly
  * IPython console missing features with respect to the old Python console
  * AttributeError is thrown when trying to get help of an object
  * Improve working directory dropdown box
  * TypeError: disconnect() failed between 'sig_prompt_ready' and all its connections
  * Missing python doc in help menu
  * Problems with backend "TkAgg" on Linux
  * NameError when running isdefined
  * Save after moving editor tabs with split panes changes wrong files
  * Symbol finder gives error message
  * Cannot run static code analysis on Spyder 3.2.4
  * Error when trying to explore empty numpy array
  * Variable explorer broken because of DeprecationWarning in ipykernel
  * Close parenthesis when unmatched
  * Crash on profiler because of lack of profiler.results
  * Can't open preferences anymore as I get an error message
  * Runtime Error raised while closing IPython Console instance
  * AttributeError: 'InternalShell' object has no attribute 'is_running'
  * Keyboard shortcuts reset button cannot be canceled/undone and too easy to trigger
  * Explicitly stated default Russian encoding on Windows not recognized
  * Automatic graphics backend throws an error
  * Can't enable debug mode
  * Spyder crashes after typing plt.plot( at the ipython console
  * Change --show-console for --hide-console
  * "Replace Selection" Erroneously Removing/Interpreting Escape Sequences
  * 'Show in external file explorer' on editor menu more than once for split panels
  * ValueError: invalid literal for int() with base 10: b''
  * Error when replacing "\" by "\\"
  * Add Clear button to (find) entry boxes
  * Don't set current working directory for external kernels
  * Error when drag and drop file from zip
  * Fast file switch and fast symbol search do not work properly if the editor is splitted
  * Exploring variables in debugging mode is giving focus to the Editor
  * Spyder always opens a new instance
  * Variable explorer should list datetime.timedelta variables
  * Spyder is not installing the PyQt5 wheel when using pip
  * Outline explorer doesn't work with second Editor window
  * Breakpoint doesn't appear in gui (red circle) but is listed in Debug > Breakpoints > List breakpoints
  * There should be a way to donate money to support the project
  + Pull Requests Merged
  * Update Japanese translation for 3.2.5
  * Update French translation for 3.2.5
  * Update Spanish translations for 3.2.5
  * Update Russian translation for 3.2.5
  * Load %%autoreload magic at kernel startup
  * Remove/update outdated refs to Mac OS X, Mac DMG installers and Continuum.io
  * Skip a test that started to fail on Windows and Python 2
  * Disable renames for list, set and tuple in the Variable Explorer
  * Make tabs drag behavior in the IPython console to be the same as the Editor one
  * Several improvements to the IPython console
  * Fix missing documentation links
  * Add PyQt5 as a new wheel dependency
  * Change pep8 check_executable for pycodestyle.
  * Change for file save on split editor when tabs are moved
  * Disable smartpants quotes in Sphinx to prevent crash with MathJax
  * Catch AttributeError while using the Help plugin
  * Adjust calls to use has_filenames return value of None
  * Simplify how pyopengl is declared in setup.py
  * Add a tooltip showing the full path of highlighted item in the working directory dropdown box
  * Improve how Matplotlib backend is set in the IPython console
  * Catch TypeError while executing code instructions in the IPython console
  * Prevent Editor dockwidget to become visible when clicking on the outline explorer if the Editor is in a separate window
  * Skip test_load_kernel_file in PyQt4 because it segfaults too much
  * Catch NameError in isdefined
  * Add validation for mimedata2url in Editor's dragEnterEvent
  * Ignore warning generated by ipykernel.datapub
  * Skip test_issue_4066 in our CIs with PyQt >= 5.9
  * Set focus for filter line when doing symbol search
  * Handle 3d empty numpy arrays
  * Change position of data loading to prevent not calling validation in the Pylint plugin
  * Change default behavior of --show-console option
  * Catch not found file error when loading profiler results.
  * Skip some dataframe tests on Linux
  * Add validation for attribute 'is_running' in the Help plugin
  * Support datetime.timedelta in variable explorer
  * Catch search regexp error while doing replace/find
  * Better feedback for regexp errors in find/replace
  * Do not overwrite unmatched braces
  * Fix ValueError when switching Python interpreters
  * Fix typo in Solarized color schemes.
  * Add confirmation message to reset shortcuts.
  * Add handling for RuntimeError while closing an IPython console instance.
  * Fix syncing of line number and plugin list for breakpoints and add unit tests.
  * Make clear line shortcut configurable in the IPython console
  * Don't unescape control characteres in replace in selection
  * Add cp1251 (default Russian) encoding on Windows to be recognized by the Editor
  * Reduce row height in dependencies dialog
  * Add clear button to find comboboxes
  * Fix bootstrap.py --debug
  * Add validation to not publish pdb_state after getting values of variables
  * Fix EditorSplitter menu_actions and add test.
  * Don't rely on process name when detecting a previous instance
  * Trade ipykernel.serialize for cloudpickle and remove use of publish_data
  * Make the fileswitcher aware of split editorstacks
- Update to Version 3.2.4
  + New features
  * Add compatibility with Jedi 0.11
  * Display lists with all types of elements in the Variable Explorer.
  + Issues Closed
  * Cannot get past splash screen
  * Sorting by column in variable explorer
  * Error in variable explorer for dicts with mixed-type keys
  * Spyder crashes because of race condition in ZMQ
  * Error when opening a new project
  * Not all lists are supported by the variable explorer
  * Error when pressing Ctrl+C in the terminal where Spyder was started
  * Increase kernel_client.hb_channel.time_to_dead even more
  * Variable Explorer: sort by values not working
  * Checking/Unchecking path in the pathmanager is not working as expected in the IPython console
  * Enter in IPython console inserts new line when big Dataframes are in namespace
  * Problem when closing files with split editors whose tabs order are not synced.
  * Variable explorer crash when viewing numpy structured array
  * Profiler incorrectly detects recursion
  * Variable explorer raise error when try to sort dict by values
  * error when closing a file
  * Error when trying to sort dataframe with duplicate columns
  * Error when Selecting Fig from Variable Explorer
  * In ipdb, the up and down keys have a strange behaviour
  * pdb.pm() raises an Error
  * Issues with recognizing directory renaming
  * Closing last open file while being in non-existing working dir raises exception
  * AttributeError: 'NoneType' object has no attribute 'execute'
  * Error when trying to edit elements of a float numpy array in variable explorer
  * Some issues with dedicated consoles
  * "Save as" dialog extremely slow
  + Pull Requests Merged
  * Add an error message when sorting a dataframe on categorical dtypes
  * Make consoles to start without an stderr file
  * Update minimal QtPy required version
  * Skip a Matplotlib test in PyQt4 because it's failing too much
  * Backport PR 5159
  * Fix crashing of the fileswitcher after closing the last file of the Editor.
  * Change spyderproject for spyproject in some missing places.
  * Add an error message when failing to serialize an object
  * Skip some tests to prevent recurrent failures and segfaults
  * Prevent a race condition with ZMQ during startup
  * Fix history browsing while debugging
  * Add handling for OSError's when changing directories.
  * Display all lists in the variable explorer
  * Add a safe getcwd function to handle errors when the current working was deleted
  * Show error when trying to sort dataframe with duplicate columns
  * Fix editing floats in array editor
  * Sync correctly the closing of files in multiple editorstacks.
  * Wait until console is ready before executing code for dedicated consoles
  * Fix some execution delays in the IPython console
  * A couple of fixes for Jedi 0.11
  * Enable sorting by values in Variable Explorer
  * Prevent unchecked paths in the pathmanager to be added to the IPython console sys.path
  * Fix recursion error in profiler
  * Prevent hard crash when inspecting certain structured arrays
  * Don't show errors when kernel_client is None
  * Fix some issues with the Editor Save dialog
  * Apply window style only if it's not None
  * Handle error when using deepcopy in the collections editor.
  * Editor historystack improvements
  * Fix calling pdb.pm() in a console
- Update to Version 3.2.3
  + New features
  * Add a button to the Variable Explorer to remove all variables at
    once.
  + Issues Closed
  * AttributeError when using outline and split code
  * 'Execute in external system terminal' unwantedly uses python2 on ubuntu16.04
  * AttributeError: 'super' object has no attribute '_handle_error' in IPython console
  * Renaming file containing folders yields IndexError.
  * pip created executable name changes between versions
  * KeyboardInterrupt error in waitingspinner
  * Debug: "Run Current Line" past the end of a script doesn't exit the debugger
  * "unblockcomment" incompatible with "automatically remove trailing spaces"
  * RuntimeError when using outline and split code editor
  * Variable Explorer: Add a button to remove all variables at once
  + Pull Requests Merged
  * Use get_python_executable to run in external terminals
  * Fix RuntimeError and AttributeError when using outline and split code editor
  * Stop creating universal wheels
  * Add handling for IndexError in the Editor when renaming folder containing file
  * Don't use super in _handle_error method of IPython console
  * Avoid KeyboardInterrupt to raise an error in waitingspinner
  * Exit the debugger if we are about to enter to sitecustomize.py
  * Fix unblock comments
  * Add a button in the Variable Explorer toolbar to reset namespace
- Update to Version 3.2.2
  + New features
  * Add a button to Find in Files to make searches case sensitive.
  * Extend Find in Files to select other search directories.
  * Add an option to set cursor blinking speed in miliseconds in
    `Preferences > General > Interface > Cursor blinking`.
  * Add checkboxes to PYTHONPATH manager to enable/disable paths.
  * Show the number of matches in the Find/Replace widget.
  + Issues Closed
  * Unable to save file in Python
  * Editor - Cannot close a (vertical) split after open
  * Word operators do not have a color style in the IPython console
  * Increase the limit of DPI setting for IPython inline graphics
  * IPython consoles can't start if Spyder temp directory is missing
  * BUG: Error editing element of numpy array in variable explorer
  * Spyder Issue when using ctrl+P : goto line
  * Unable to start Array builder using keyboard shortcut
  * Console slow to close when debugging
  * Consistent layout in different panes
  * "Replace selection" adds "\." anytime the string to be added contains "."
  * IPython: Run Code at Startup - Magics
  * Force-stop does not work on hanged progress.
  * Run Configuration per file: Working Directory not remembered
  * Error when trying to load third-party plugins
  * Pressing Ctrl+Tab wanting to switch to another tab raises an IndexError
  * Make Spyder remember tab order
  * Kernels fail to start because they can't create stderr files in non-ascii accounts on Windows
  * SPYDER_DEBUG=3 is failing on Windows
  * Find in Files should have ignore case flag
  * Extend Find in Files to select other directories
  * Array editor: Change default float formatter from %%.3f to %%.6g
  * Debug: If a breakpoint is on the first line of a script the whole script runs
  * Exceptions swallow the prompt!
  * Add icon to mac dock when running with bootstrap
  * Editor autocompletion and help extraction not working in Spyder 3.1.4
  * Option to Disable Blinking Cursor
  * Spyder stops executing commands if Variable explorer shows complicated objects
  * Ctrl+F should show the number of appearances in the file as #current/#total
  * Spyder 3 opens a command prompt window when running certain commands
  * Add the possibility to disable entries in the PYTHONPATH manager
  + Pull Requests Merged
  * Skip package names that end in certain suffixes when loading third-party plugins
  * Correctly move to first breakpoint after entering debugging
  * Fix error when creating some error messagebox
  * Add handling for non existing indexes in IPython Console clients
  * Add more handling to actions with reference deleted
  * Deactivate editor actions when Tab Swither is shown
  * Skip some tests in our CIs
  * Don't run continue when starting debug if there is a breakpoint in the first line with code.
  * Create Spyder TEMPDIR if it does not exist when creating new consoles
  * Fix cwd issues in the "Run > Configuration per file" dialog
  * Increase waiting time and repetitions for tests that enter debugging
  * Fix 1D Numpy arrays edition in the Variable Explorer
  * Make inactive paths to be ignored when Spyder's path list is synchronized with PYTHONPATH on Windows
  * Increase dpi limit of inline plots
  * Allow values with '%%' in config system
  * Add a style for word operator tokens in the IPython pygments dictionary
  * Make value_to_display more robust
  * Increase tries for a couple of flaky tests
  * Add test with non-ascii directory for consoles stderr file
  * Fix setting SPYDER_DEBUG variable on Windows
  * Fix handling of line count in the fileswitcher
  * Prevent subprocess.Popen calls to create visible consoles on Windows.
  * Remove regex escape characters from replacement string on the Find/Replace widget
  * Fix shortcut to make array builders appear in the IPython Console
  * Minor fixes in Find in Files
  * Stop console before closing it
  * Send Spyder python path to introspection plugins
  * Reduce row height in shortcut dialog
  * Clean Spyder config before re-running our tests
  * Change format in array and dataframe editors
  * Unify layout for panes and widgets
  * Display prompt after errors
  * Preserve order when saving/loading files from a project.
  * Extend Find in Files to select other search directories
  * Add a button to Find in Files to make searches case sensitive
  * Add an option to set cursor blinking speed in miliseconds
  * Add checkboxes to PYTHONPATH manager to enable/disable paths
  * Add icon earlier when running application
  * Show the number of matches in the Find/Replace widget
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to version 3.2.1
  * See: https://github.com/spyder-ide/spyder/blob/v3.2.1/CHANGELOG.md
- Update dependencies
* Mon Oct 17 2016 jengelh@inai.de
- Update descriptions
* Fri Oct 14 2016 toddrme2178@gmail.com
- Fix pylint dependency.
* Thu Oct 13 2016 toddrme2178@gmail.com
- Update to version 3.0.0
  * See: https://github.com/spyder-ide/spyder/blob/3.x/CHANGELOG.md
- Remove spyderlib subpackage.  spyderlib no longer exists.
  Everything that was in spyderlib is now in the spyder namespace.
- Split plugins into their own subpackages.  Plugins are each in
  their own namespace, and third-party plugins are now possible.
  Further, some plugins can pull in dependencies that some users
  may not want.
- Update URL to new upstream URL.
- Add additional dependencies.
- Check which dependencies are really needed and which ones are
  optional and divide them into Requires and Recommends
  appropriately.
* Thu Jun  9 2016 toddrme2178@gmail.com
- Update to Version 2.3.9
  * Issue #3067 - File left open in sitecustomize when executing it in Python 3
  * Issue #3031 - Variable Explorer freezes when certain binary data is loaded
  * Issue #2991 - RuntimeWarning with pandas.dataframes that contain np.nan values
  * Issue #2984 - Can't access Preferences in spyder
  * Issue #2983 - Freeze while assigning data from numpy array when the data is a string
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Wed Mar  9 2016 toddrme2178@gmail.com
- Update to Version 2.3.8
  + New features
  * Python and IPython consoles
  * Fix a sitecustomize error when using Matplotlib 1.5 with Python 2 on Linux
  * Variable Explorer
  * Add support for Pandas Series when using Pandas 0.17+
  * Fix a freeze when creating empty DataFrames in Python 2
  * Fix a freeze when working with big Numpy recarray's
  * Under the hood
  * Avoid startup crashes when there are errors importing Numpy, SciPy or Pillow
  + Bug fixes
  * [Issue 2819](../../issues/2819) - Spyder fails to start because of an error with scipy
  * [Issue 2815](../../issues/2815) - Variable explorer is not recognizing Pandas Series objects
  * [Issue 2793](../../issues/2793) - Connecting to kernel fails because of update to Matplotlib 1.5
  * [Issue 2791](../../issues/2791) - DataFrame with no rows gives error when trying to view it
  * [Issue 2783](../../issues/2783) - Spyder freezes on assigning a fits table data
  * [Issue 2744](../../issues/2744) - Spyder hangs when creating an empty DataFrame on Python 2
- Fixes bug BNC#966417
* Tue Oct 27 2015 toddrme2178@gmail.com
- Remove optional dependencies from BuildRequires
* Tue Oct  6 2015 toddrme2178@gmail.com
- Update to 2.3.7
  + New features
  * Editor
  * Remove support for Jedi 0.9 because it was causing crashes
  * Variable Explorer
  * Fix crashes and freezes when working with DataFrames on Python 2
  * Under the hodd
  * Restore support for PySide
  + Bug fixes
  * Issue 2709 - IPython console error when trying to use SymPy
  * Issue 2693 - README should link to manual
  * Issue 2689 - "Resize" button in variable explorer chops off the array
  * Issue 2684 - Applications directory link is broken in Spyder 2.3.6 dmg's
  * Issue 2680 - "Close all files" hangs Spyder
  * Issue 2661 - Conda package manager is packed in 2.3.6 win32 distribution leading to errors
  * Issue 2659 - Crash while getting completions of DataFrames on the Editor because of Jedi 0.9
  * Issue 2654 - Creating DataFrames in Python or IPython consoles make Spyder 2.3.6 to hang
  * Issue 2649 - PySide can not be used on 2.3.6
  * Issue 2296 - Line numbers misaligned when zooming and scrolling in Mac
  * Issue 2036 - Code analysis and tooltips are not displayed in Ubuntu
  + Pull requests
  * PR 2650 - Failed sip import blocks fallback to PySide
* Fri Aug 28 2015 toddrme2178@gmail.com
- Update to 2.3.6
  + New Features
  * IPython Console
  * Make it fully compatible with IPython/Jupyter 4.0
  * Variable Explorer
  * Don't refresh it when focused to avoid slow downs when
    working with big data
  * Add variable name to DataFrame editor
  * Fix several crashes and freezes when working with DataFrames
  * Under the hood
  * Use PyQt4 API #2 by default (API #1 is not supported anymore).
    This is necessary to support IPython/Jupyter 4.0
  + Bug fixes
  * Multiple untitled files generate at close
  * Indenting at the first position in file fails/crashes
  * Crash after update IPython to 4.0
  * Call tips and auto completion tips go out of screen on a second monitor
  * Having a lof of data in the Variable explorer slows down Spyder considerably
  * Spyder crash on launch with Babel 2.0/Python 3.4
  * List of pandas dataframes in variable explorer slows down Spyder
  * Variable explorer auto-refreshes after kernel restarts
  * DataFrames with headers that contain BOM utf-8 data are freezing/crashing Spyder (in Python 2)
  * Spyder crashes when displaying DataFrames with duplicate column names in the Variable Explorer
  * Don't ask to confirm exit on default untitled files
  * Display object name in DataFrame editor
  + Pull requests
  * Fix missing exception on Windows when importing data on the Variable Explorer
  * Show call tips at right position when there are multiple screens
  * Fix error when indenting on the first line of a file
- Switch dependencies to jupyter versions
* Mon Jun 29 2015 toddrme2178@gmail.com
- Update to 2.3.5.2
  * Note: Versions 2.3.5 and 2.3.5.1 have serious startup bugs on
    Windows and Mac respectively. Hence they are not listed here.
  * New features
  - Editor
    + Add support for Jedi 0.9
  - IPython Console
    + Add initial support for IPython/Jupyter 4.0
  - Main Window
    + Improve how Spyder looks in MacOS X
    + Several fixes to prevent startup crashes
  * Bug fixes
  - Issue 2468 - 'Connect to existing kernel' fails if json file not in PWD
  - Issue 2466 - No Notification of Running Instance
  - Issue 2463 - Failure to preserve Matplotlib backend when using symbolic math
  - Issue 2456 - Launching IPython console fails because of errors importing Pandas or Matplotlib
  - Issue 2452 - os.system causes TypeError in Python 3
  - Issue 2448 - Spyder crashes using Variable Explorer with BeautifulSoup
  - Issue 2446 - When importing putting two periods in a row produces an error in a Python console
  - Issue 2363 - Spyder fails to start because of problems with lockfile
  - Issue 2356 - Block comment incorporating whitespace excludes last line
  - Issue 2341 - IPython console: "sre_constants.error: unbalanced parenthesis" while typing
  - Issue 2314 - Cell highlighting not updated after closing the FindReplace widget
  - Issue 2302 - Closing all files in editor shouldn't leave it empty
  - Issue 2299 - IPython preference "Automatically load Pylab and Numpy Modules" not followed
  - Issue 2298 - Cannot stop executing when runing a flask app with debug=True
  - Issue 2285 - Copying from Spyder and pasting into LibreOffice displays strange comments
  - Issue 2228 - Shortcut to run cells on Mac is not working
  - Issue 2188 - can't run win_post_install from pip
  - Issue 2171 - Spyder Mac apps (for Python 2 and 3) hang on startup with OSX 10.9.5
  - Issue 2028 - Background color of theme is not set properly on Mac OSX
  - Issue 1957 - Python 3 Mac app can't start Python or IPython consoles
  - Issue 1844 - "Set as current console's working directory" button not working on Python 3
  - Issue 1615 - Mac app - Matplotlib does not work with Canopy
  * Pull requests
  - PR 2486 - Stop using IPython.lib.kernel 0.13.2 shim and add initial support for Jupyter
  - PR 2484 - Remove unnecessary changes to detected kernel json file when connecting to external kernels
  - PR 2434 - Match for pylint when parsing pylint version
  - PR 2411 - Improve github issue template
  - PR 2377 - Fix the fact that spyder_win_post_install.py can't be run from pip
  - PR 2293 - Hide menu icons on Mac OS X
  - PR 2247 - Add support to run Python programs on xfce and xterm external terminals
  - PR 2216 - Fix broken png files: libpng 1.6.2 and newer has stricter iCCP rules
* Tue Mar 24 2015 toddrme2178@gmail.com
- Update to 2.3.4:
  * New features
  - Debugging
    + After pressing the Debug button (or Ctrl+F5) move to the first
    breakpoint
  - IPython Console
    + Drop support for Sympy versions less than 0.7.3
  - Python Console
    + Remove support to run system commands with ! (like !diff)
  - Editor
    + Accept drops from compressed files on Windows
  * Bug fixes
  - spyder crashes if ipython installed but not pygments
  - Cannot plot inline in IPython console on Linux
  - Update French translations for 2.3.4
  - Importing a module with debugger causes "TypeError: decoding Unicode is
    not supported"
  - SyntaxErrors with Python 3.2
  - Object Inspector is not showing "No documentation available" for objects
    without docstring
  - IPython does not work with brewed or virtualenv Python(s) in MacOSX
  - Spyder2.3.3 Code completion breaks
  - Spyder's WM_CLASS is empty, resulting in unexpected behavior for task
    managers
  - Code completion issue with Jedi
  - IPython consoles are not named correctly when connecting to existing
    kernels and passing the full kernel path
  - runfile with path containing apostrophes (quotes) will not work
  - Long NumPy arrays throw off errors
  - Special character "!" is not processed correctly when debugging in Python
    consoles
  - Spyder crashes on Windows because of non-ascii chars in working directory
  - Don't execute external commands (!) when running pdb in python consoles
  - Execute until first breakpoint when pressing the Debug button
  - Dragging (not dropping) file from 7zip over spyder window causes
    TypeError in dragEnterEvent
  - spyderlib.utils.external overrides modules for script execution
  - spyder 2.3 ipython console startup code or file not working
  - Running in external system terminals is not working on Windows and Python
    3
  - Spyder crashes on launch trying to load the project config file
    (.spyderproject)
  - raw_input borks with '!'
  - Plot A List Of Floats In Variable Explorer Not Possible
  - Problems with sitecustomize because of pickleshare library
  - "Highlight occurrences" setting is lost after IDE restart
  - Mac app - Sometimes it's not possible to get the user env vars
  - The PYTHONPATH manager on the Mac app does not work with the EPD64
    interpreter
  - Ctrl-C doesn't copy to clipboard in object inspector
  * Pull requests
  - Update French translations
  - Improve message for no docstring
  - catch a reason to crash on startup
  - Fix a bug in completion if callback value is not converted to string
  - Open configuration file with utf-8 encoding on Windows and Python 2
  - Fix zlib segmentation fault in Anaconda 3.4 Linux
- Update to 2.3.3:
  * New features
  - Editor
    + Use the Jedi library to do code completions
    + Add Ctrl+= as a shortcut to do Zoom in and Ctrl+0 to reset zoom
    + Add an option to show blank spaces, under the Source menu. There is
    also an option to make this permanent under Preferences > Editor.
  - IPython Console
    + Don't print DataFrames as html tables because this won't be supported
    since IPython 3.0
    + Drop support for IPython 0.13
    + Support the upcoming 3.0 version
    + Add Ctrl+T as shortcut to open new consoles
    + Simplify how consoles are named
  - Variable Explorer
    + More optimizations to handle big DataFrames and NumPy arrays (i.e. with
    more than 1e6 elements).
  - Main Window
    + Add Ctrl+W and Ctrl+F4 to close tabs in all platforms
    + Show shortcuts to move to each pane in View > Panes
  * Bug fixes
  - Visual help for indentation: draw spaces and tabs
  - Allow the file explorer to open any file into the editor as text
  - Augment or replace rope with Jedi
  - Kill button 'clicked' signal is connected but never disconnected on the
    python shell
  - Add support to get code completions for compiled modules (e.g. OpenCV)
  - Debug ignores breakpoints, if there's no ASCII characters in a file path
  - Creating file gives TypeError on Python 3
  - Keyboard shortcut to come back to normal zoom level
  - Shortcuts to create and close IPython consoles
  - Transition to git and github
  - Evaluating cell or selection in Python consoles takes ages
  - Spyder with GTK/GTKAgg backend on GNOME freezes
  - Matplotlib backend in Mac can't be changed when using PySide
  - exception in spyder internal console when typing 'exit(' in editor
  - autocomplete in the middle of a word
  - Your IPython frontend and kernel versions are incompatible
  - Winpdb (F7) doesn't work in Python 3
  - TkAgg backend unresponsive window on Linux and OS X
  - Improve inline backend options
  - Pandas Dataframe not opening in Variable Explorer
  - "About spyder" and "Report issue ..." output errors
  - Profiler - sorting by Total Time sorts by string order, not numeric order
  - Unable to bring up tutorial
  - Bug on Variable Explorer while viewing DataFrames, with timestamp columns
  - Missing py27 dmg download
  - PYTHON pathmanager on windows 8 does not work properly
  - Spyder 2.3.2 freezes when viewing big collections on the Variable
    Explorer
  - UnicodeDecodeError in the Internal console when trying to run a file with
    non-ascii chars and synatx errors in it
  - Go to definition menu item inactive with rope present.
  - iPython console rendering of pandas.DataFrame.repr_html() note in
    changelog
  - Small typo in Help : Plotting examples
  - Closing takes a long time with Python 3.4
  - UnicodeDecodeError when inspecting pandas DataFrame in ipython console
  - Update French translations for 2.3.3
* Sat Dec  6 2014 toddrme2178@gmail.com
- Update to 2.3.2:
  * Editor
  - Improve cells visualization
  - Add support for drag selection and improve look of
    line number area
  - Open on it any text file present in the Variable Explorer
  - View and edit IPython notebooks as Json files
  - Syntax highlighting for Json and Yaml files
  * Variable Explorer:
  - Import csv files as Pandas DataFrames
  - Improve browsing speed for NumPy arrays and DataFrames with more
    han 1e5 elements
  * IPython Console
  - Add a stop button to easily stop computations
* Mon Oct 13 2014 toddrme2178@gmail.com
- Fix icon directory ownership
* Thu Sep 18 2014 toddrme2178@gmail.com
- Update to 2.3.1
  * New features since
  * Variable Explorer
  * Support for Pandas DataFrame's and TimeSerie's types
  * Support for Numpy 3D arrays
  * Drag and drop works for all its supported file types
    (e.g. images, mat files, json files, etc)
  * Editor
  * F9 runs the current line under the cursor if nothing is
    selected
  * Focus remains on it after evaluating cells and selections
    (an option was added to return to the old behavior)
  * IPython console
  * Connect to external kernels through ssh
  * Object Inspector
  * Add a tutorial for beginners
  * Main Window
  * Improve style on Mac
  * Bug fixes
  * Issue  93  Variable explorer: allow array editor to deal
    with arrays with more than 2 dimensions
  * Issue  1160  Variable Explorer: add support for pandas
    objects
  * Issue  1305  mayavi plot hangs when IPython graphics backend
    is inline (default)
  * Issue  1319  Spyder is not getting its taskbar icon right in
    Win 7/8
  * Issue  1445  Linux style middle mouse button paste not
    executed in console
  * Issue  1530  Wrong encoding for date in pylint widget
  * Issue  1590  Add numpy matrices as a supported type to the
    Variable Explorer
  * Issue  1604  spyder 2.2.5 freezes with netCDF4-python
  * Issue  1627  Run selection (F9) changes focus to Python
    interpreter, but ex-Matlab users expect the
    focus to remain on the editor
  * Issue  1670  Provide a "Run current line" feature
  * Issue  1690  Feature request: connect to existing IPython
    kernel over ssh
  * Issue  1699  Option to disable middle button paste
  * Issue  1783  The new cell delimiter when converting a
    notebook to python file is # In[`*`]
  * Issue  1863  Ctrl-C doesn't work in a *restarted* IPython
    console
  * Issue  1893  Matplotlib plots do not display correctly in
    2.3.0 (when running in dedicated python
    interpreter)
- Update dependencies
* Thu Jul 17 2014 toddrme2178@gmail.com
- Add spyder3-rpmlintrc to sources
- Remove unused version_check.patch
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 2.3.0 final
  - New features
  * Python 3 support
  * Editor
  * Use the Tab key to do code completions
  * Highlight cells, i.e. portions of a file delimited by separators of the form `# %%%%`
  * First-class support for Enaml files
  * Syntax highlighting for Julia files
  * Use Shift+Tab to show the signature corresponding to a function/method while it's been called
  * Do code completions using the tokens (or words) found in a file
  * Token-based completions work for any file type supported by the Editor
  * Add a new tooltip widget (borrowed from the IPython project) to better handle how to show function signatures
  * IPython console
  * Assign the keyboard shortcut Ctrl+Shift+I to move to it
  * Open a console by default at startup
  * Give visual feedback when opening a console
  * Show kernel error messages in the client tab
  * Object Inspector
  * Add an intro message to explain how to use it
  * New style based on the Bootswatch Cerulean theme
  * Main Window
  * Reorganize several menus
  * Under the hood
  * Improve startup time
  * Develop a new way to update configuration defaults (that doesn't involve resetting user settings)
  - Bug fixes
* Fri May 30 2014 toddrme2178@gmail.com
- Initial python 3 version
- Update to 2.3.0rc
  * No upstream changelog
* Fri Feb 14 2014 dmueller@suse.com
- remove python-pylint buildrequires, doesn't seem  to be used
* Wed Nov 13 2013 p.drouand@gmail.com
- Define %%{python_sitelib} to fix build with SLE
* Tue Oct 15 2013 toddrme2178@gmail.com
- Update to version 2.2.5
  * Issue  1322  Problems with scientific_startup in other interpreters from the one Spyder is running on
  * Issue  1337  Mac app - Update to Qt 4.8.4 for HDPI
  * Issue  1450  IPython kernel cpu usage increases with time
  * Issue  1520  LinuxColor for ipython plugin
  * Issue  1551  /doc/installation.rst: update Arch Linux package link
  * Issue  1560  spyder 2.2.3 incompatible with pylint 0.25.1 on Windows
  * Issue  1564  Fix several Editor cell problems
  * Issue  1578  Typo in your 'About Spyder...' dialog.
  * Issue  1581  Cannot launch Spyder 2.2.4 installed from DMG on Mac OS X.
  * Issue  1589  Mention what types of objects our Variable Explorer support in our docs
  * Issue  1595  Fail to start an ipython console when variable explorer autorefresh is turned off in Preferences
  * Issue  1596  Spelling mistake in dialog ('loose' --> 'lose')
  * Update our Mac application to the latest versions of Python, Qt and PyQt (now it's based in Homebrew).
  * Several important compatibility fixes for PySide.
  * Improve our support for IPython 1.0+.
* Sat Oct 12 2013 p.drouand@gmail.com
- Update to version 2.2.4 (bnc#849811)
  * Fix issue 347: Matplotlib hangs on Mac if using PySide
  * Fix issue 1265: Create a Debug menu to easily show how to set breakpoints
  * Fix issue 1489: Project Explorer does not load all projects in workspace.
  * Fix issue 1516: Make Spyder compatible with both IPython 0.13 and 1.0
  * Fix issue 1531: Pyflakes version check is looking for 0.5.0 only
  * Fix issue 1539: /tmp/spyder is owned by the first user on the server
    to launch spyder
  * Make Spyder compatible with SymPy 0.7.3+
  * Add shortcuts to the tooltips of all toolbars
  * Make IPython Console work better if Matplotlib is not installed
- Changes between version 2.2.3 and 2.2.2
  * Fix issue 634: Debugging: Lingering break points
  * Fix issue 639: Project Explorer: horizontal size issue (added an
    optional horizontal scrollbar. This option may be enabled/disabled
    in the widget context menu)
  * Fix issue 749: Outline Explorer: Duplicate entries
  * Fix issue 852: Implement matlab-like cell features
  * Fix issue 1388: Add an "About Spyder dependencies" dialog box
  * Fix issue 1438: "runfile" doesn't work correctly if unicode_literals has
    been imported (replaced backslashes by slashes in paths)
  * Fix issue 1515: Add an option to use the same interpreter Spyder is
    running on as "Python executable" for external consoles
  * Fix issue 1522: licenses of the images (especially the .png)
  * Fix issue 1526: Build script (setup.py) includes the wrong version of
    pyflakes/rope in Windows installer
  * Fix issue 1527: please include the LICENSE file in the source package
  * New "Run selection" (F9), "Run cell" (Ctrl+Enter) and "Run cell and
    advance" (Shift+Enter) actions in "Run" menu entry, as a replacement
    to the old "Run selection or block" and "Run block and advance" actions.
  * Added "Optional Dependencies" dialog box in "?" menu.
  * Editor: added Monokai and Zenburn syntax coloring schemes.
  * Keyboard shortcuts: removing deprecated shortcuts at startup. Otherwise,
    when renaming the name of a registered shortcut (in the code), the old
    shortcut will stay in Spyder configuration file and opening the Preferences
    dialog will show a shortcut conflict dialog box.
  * External console tabs: fixed history browsing with Ctrl+Tab and added
  Shift+Ctrl+Tab support.
  * Preferences>Console>Advanced: new option to switch between the default Python
  executable
  * Run Icons: removed deprecated images, updated other images to the new design
    setup.py/Windows installers: now building CHM documentation for Windows
  * SPYDER_DEBUG environment variable now supports 3 levels of debug mode:
    SPYDER_DEBUG=0 or False: debug mode is off
    SPYDER_DEBUG=1 or True: debug level 1 is on (internal console is disconnected)
    SPYDER_DEBUG=2: debug level 2 is on (+ logging coms with external Python processes)
    SPYDER_DEBUG=3: debug level 3 is on (+ enabling -v option in external
    Python processes and debugging editor)
- Changes between version 2.2.2 and 2.2.1
  * Fix issue 1497: Spyder 2.2.1 does not work with Python < 2.7
  * Fix issue 1498: TypeError thrown by IPython Console when the pager is off
  * Fix issue 1499: Console (Terminal) throws NotImplementedError for Home/End keys
  * Fix issue 1509: Add support for javascript syntax highlighting
  * Fix issue 1510: Problems with zooming in/out
  * Add new icons to the Run, Debug and Main toolbars
  * Update Pylint plugin to work with pylint 1.0
  * Add Ctrl/Cmd+[+,-] to zoom in/out in the Editor
  * Disable Crtl+MouseWheel to zoom in/out in Mac (See  Issue 1509 )
  * Update Pandas and Matplotlib in our Mac application
* Tue Aug 13 2013 speilicke@suse.com
- Updato to version 2.2.1 (bnc#833564):
  + Upstream provides no changelog
- Install documentation into correct location
* Mon Apr 22 2013 hrvoje.senjan@gmail.com
- Added version_check.patch, fixes detection of pyqt version
* Thu Feb 14 2013 fisiu@opensuse.org
- Update to version 2.1.13:
  * Bug fixes
* Thu Nov 29 2012 toddrme2178@gmail.com
- Fix typo
* Thu Nov 29 2012 toddrme2178@gmail.com
- Update to Version 2.1.11
  * Bug fixes
- Split documentation package
- Split spyderlib package and binary package, since spyderlib is
  used independently of the spyder gui
- Spec file cleanups
* Tue Jun 12 2012 toddrme2178@gmail.com
- Install desktop file, with appropriate icon
- Tag documentation in spec file
- Fix rpmlint warnings
* Mon May 28 2012 toddrme2178@gmail.com
- Update to Version 2.1.10
  * Bug fixes
* Tue May 22 2012 toddrme2178@gmail.com
- Update dependencies
- Clean up spec file formatting
- Update to Version 2.1.9
  * Bug fixes
- Update to Version 2.1.8
  * Bug fixes
- Update to Version 2.1.7
  * Bug fixes
  * Variable explorer/Array editor: added support for masked arrays
  * Showing Spyder's internal console automatically when there is a traceback
  * Do not crash when a 3rd party plugin failed to import
  * Editor:
  * Automatic insertion of single, double and triple quotes
  * Automatically colons insertion when pressing Enter after 'if', 'def', etc
  * Don't trigger code completion on comments if text ends with a dot
  * Added keyboard shortcut (Ctrl+Shift+Escape) to clear the console
  * Added keyboard shortcut (Ctrl+P) to print current file (thanks to fheday at gmail dot com for the contribution)
  * Code introspection features (code completion, calltips, go-to-definition) are now working even if script has syntax errors
- Update to Version 2.1.6
  * Bug fixes
- Update to Version 2.1.5
  * Bug fixes
  * Debugging: when a non-empty SPYDER_DEBUG environment variable exists, Spyder switch to debug mode (log files are created in user's home directory and debug prints are available in the terminal)
  * Variable explorer/Dictionary editor: added option to plot histogram from a 1-D array
  * Console:
  * standard Python interpreter is now a real Python interactive session: the older implementation was running a startup script and tried to emulate a standard Python interactive session (changing attributes like __name__, running the PYTHONSTARTUP script, etc.). But this implementation was not close enough to the standard Python interactive session, i.e. when you execute `python` outside Spyder, without any argument. A recent bug report confirmed this: the PYTHONSTARTUP script was executed but not exactly the same way as it is outside Spyder: for example, doing `from __future__ import division` in the startup script had no effect whereas it did outside Spyder.
  * when running a standard Python interpreter, instead of running the startup script (spyderlib/widgets/externalshell/startup.py), the shell widget (ExternalPythonShell) simply runs the python executable with -u -i options, that's all. So now, the PYTHONSTARTUP script is executed as expected.
  * Scientific startup script (default PYTHONSTARTUP in Spyder): added floating point division (from __future__ import division)
  * PySide support:
  * Added new "Qt (PyQt/PySide)" settings group in "External modules" tab
  * It is now possible to select the Qt-Python bindings library: default (i.e. depends on the QT_API environment variable), PyQt or PySide
  * The PyQt input hook has been adapted for PySide, so it is now possible to do interactive (non-blocking) plotting with PySide
  * New options for standard Python interpreters (no effect on IPython):
  * "Merge process standard output/error channels": merging the output channels of the process means that the standard error won't be written in red anymore, but this has the effect of speeding up display
  * "Colorize standard error channel using ANSI escape codes": this method is the only way to have colorized standard error channel when the output channels have been merged
  * Internal console (Issue 868): output is now immediately available
  * "Maximize current plugin" action: now automatically shows the "Outline" plugin when maximizing the "Editor" plugin
  * Editor/Outline comment separators: allow space betwee hash and dash, e.g "# --- Outline Separator"
- Update to Version 2.1.4
  * Bug fixes
  * Console:
  * option "Open an IPython interperter at startup" is now *explicitely* disabled for IPython v0.11+ (these versions of IPython are not fully supported through Spyder's console plugin)
- Update to Version 2.1.3
  * Bug fixes
  * Variable explorer performance were improved, especially when dealing with very long sequences -- See this discussion: http://groups.google.com/group/spyderlib/browse_thread/thread/3a7ef892695e417a
  * Variable explorer / dictionary editor: added support for unknown objects -- this allows browsing any object attributes -- This is still experimental.
- Update to Version 2.1.2
  * Bug fixes
  * File/Project explorer:
  * Added "Delete" keyboard shortcut to remove selected file(s)/folder(s)
  * SCM integration: added support for !TortoiseHg v2 (only v1 was supported)
  * Console/Matplotlib options: the backend may now be set separately from the Matplotlib patch
  * Console:
  * The Matplotlib patch is only applied for Matplotlib <=v1.0
  * !PyQt API version issues (error like "!ValueError: API 'QString' has already been set to version 1"): the "ignore setapi errors" option is disabled by default, to avoid masking these errors and associated tracebacks
- Update to Version 2.1.1
  * Bug fixes
- Update to Version 2.1
  * Bug fixes
  * New *Profiler* plugin (thanks to Santiago Jaramillo)
  * New experimental *IPython* plugin embedding IPython's Qt console: see [http://spyder-ide.blogspot.com/2011/08/preview-of-new-ipython-plugin-for.html here]
  * General:
  * Main window:
  * added "Custom window layouts" management (see menu "View")/handling 3 custom layouts: default shortcuts Shift+Alt+FX to switch to/from layout #X and Ctrl+Shift+Alt+FX to set layout #X
  * "General" preferences page: added option to set the Qt windows style, depending on platform (Plastique, Cleanlooks, CDE, Windows...)
  * Menu "?": added menu entry to report Spyder issues, filling automatically informations on your configuration
  * Reorganized "Run"/"Source" menu, added "Interpreters" menu
  * Fixed application name for Gnome 3/Fedora 15
  * Command line options: added option "--defaults" to reset settings (stored in .spyder.ini) to defaults (a lot of settings are preserved: shortcuts, window layouts, ...) -- this is less brutal than "--reset" which reset all settings by removing all configuration files related to Spyder
  * *Outline* (function/class browser) is now a plugin in itself, embedded in its own dockwidget: Spyder's window layout is even more customizable than before
  * *Code completion*
  * (Editor/Console): entries starting with an underscore character are now placed to the end of the suggested list
  * (Editor/Console): Import statements are now completed correctly
  * *Console*:
  * Major code cleaning: running Python applications in Spyder has never been cleaner and is very close to a simple Python interpreter
  * Added built-in function `open_in_spyder` to open a file in Spyder's source code editor from the console
  * Standard Python interpreter:
  * now refresh the variable explorer at each new prompt (even if auto-refresh is disabled -- actually, this is the typical use case)
  * added support for basic special commands (%%pwd, %%ls, %%clear) and system commands (starting with '!', e.g. !dir or !ls)
  * added [http://spyder-ide.blogspot.com/2011/09/new-enhanced-scientific-python.html "scientific" startup script] with support for numpy, scipy and matplotlib
  * Preferences (External modules tab):
  * added an option to set !PyQt API to v1 or v2 -- this avoids issues with Enthought Tool Suite or any other library/program using !PyQt API v2 which is *not* the default API for Python 2
  * changed matplotlib patch to fix compatiblity issue with !PyQt API v2
  * Preferences (Advanced Settings tab): added option "Python executable" to customize path to Python interpreter executable binary
  * *Variable explorer*:
  * New HDF5 plugin ([http://code.google.com/u/DavidAnthonyPowell/ DavidAnthonyPowell]): import/export HDF5 files to/from the variable explorer
  * Dictionary editor/Variable explorer:
  * Added support for more NumPy data types
  * Added action "Resize rows to contents" (partially implements feature requested with Issue 807)
  * *Editor*:
  * find/replace:
  * added support for *multiline* regular expression search pattern
  * added support for *multiline* regular expression text replacement
  * added button "Highlight matches" to highlight all found results
  * syntax highlighting: added support for OpenCL, gettext files, patch/diff files, CSS and HTML files
  * support for "2 spaces" and "tabs" indentation characters
  * new code analysis feature: added support for the [http://pypi.python.org/pypi/pep8 pep8] style guide checker
  * "Comment" and "Uncomment" actions were replaced by a single "Comment/Uncommment" toggle action
  * (Fixes  Issue 811 ) "Run configuration": added "Run in an external system terminal" option
  * *File explorer* and *Project explorer*:
  * great performance improvement (using a multithreaded file system model)
  * Added minimalist SCM support (Mercurial and git are currently supported)
  * *File explorer*: added an option to "Show current directory only"
  * *Project explorer*: this plugin was entirely rewritten to improve performances and usability
  * *Pylint plugin*:
  * added option to save file before analyzing it
  * *Spyder's console embedded in your application (spyderlib.widgets.internalshell):
  * in traceback, a clickable link now opens the associated file in Spyder (if application was launched from Spyder with monitor enabled)
  * Application sample embedding Spyder's internal shell: upgraded to guidata v1.4+ (simplified build script a lot!)
- Update to Version 2.0.12
  * Bug fixes
  * (Fixes Issue 655) Editor/pyflakes-powered code analysis: warnings are now ignored for lines containing "pyflakes:ignore"
  * Internal console (Spyder debugging only): turned off the multithreaded mode
- Update to Version 2.0.11
  * Bug fixes
  * File explorer widget/plugin: improved performances (widget is now populated in a separate thread)
  * Spyder crash dialog: warning the user about the '--reset' option (this will remove all configuration files)
* Sun Apr 17 2011 saschpe@gmx.de
- Initial version (2.0.10)
